@@ -1,5 +1,5 @@
 /*  GNU Robbo
- *  Copyright (C) 2002-2009 The GNU Robbo Team (see AUTHORS).
+ *  Copyright (C) 2002-2010 The GNU Robbo Team (see AUTHORS).
  *
  *  GNU Robbo is free software - you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -66,18 +66,6 @@
 #define ROB_SPRITES_POINTER_SHADOW_Y 4
 #define ROB_SPRITES_POINTER_SHADOW_W 13
 #define ROB_SPRITES_POINTER_SHADOW_H 19
-/* #define ROB_SPRITES_MINIMISE_XOFFSET 26	Redundant: won't ever be used as they'll be in the skin.
-#define ROB_SPRITES_MINIMISE_W 24
-#define ROB_SPRITES_MINIMISE_H 14
-#define ROB_SPRITES_MAXIMISE_XOFFSET 50
-#define ROB_SPRITES_MAXIMISE_W 24
-#define ROB_SPRITES_MAXIMISE_H 14
-#define ROB_SPRITES_RESTORE_XOFFSET 74
-#define ROB_SPRITES_RESTORE_W 24
-#define ROB_SPRITES_RESTORE_H 14
-#define ROB_SPRITES_EXIT_XOFFSET 98
-#define ROB_SPRITES_EXIT_W 24
-#define ROB_SPRITES_EXIT_H 14 */
 
 /* Variables */
 ROB_OpEnv rob_op_env;
@@ -100,8 +88,6 @@ int ROB_GetCanvasOffset(ROB_Object *rob_object, int *cx, int *cy);
 int ROB_GetVisibility(ROB_Object *rob_object);
 int ROB_GetEnability(ROB_Object *rob_object);
 int ROB_GetAlpha(ROB_Object *rob_object);
-int ROB_GetAlphaOver(ROB_Object *rob_object);
-int ROB_GetAlphaPress(ROB_Object *rob_object);
 ROB_Object *ROB_GetObjectUnderObject(ROB_Object *rob_object, int hitpoint);
 int ROB_FindAncestor(ROB_Object *rob_object, ROB_Object *target);
 void ROB_ManagePointerInput(int pxu, int pyu);
@@ -166,7 +152,6 @@ void ROB_Init(ROB_OpEnv *op_env) {
 	rob_object.visible = TRUE;
 	rob_object.enabled = TRUE;
 	rob_object.alpha = 255;
-	rob_object.alpha_over = 255;
 	if (ROB_CreateObject(&rob_object)) printf("%s: %s\n", __func__, ROB_GetError());
 	/* Create a canvas object */
 	if (ROB_SetObjectDefaults(&rob_object)) printf("%s: %s\n", __func__, ROB_GetError());
@@ -175,7 +160,6 @@ void ROB_Init(ROB_OpEnv *op_env) {
 	rob_object.visible = TRUE;
 	rob_object.enabled = TRUE;
 	rob_object.alpha = 255;
-	rob_object.alpha_over = 255;
 	rob_object.w = screen->w;
 	rob_object.h = screen->h;
 	if (ROB_CreateObject(&rob_object)) printf("%s: %s\n", __func__, ROB_GetError());
@@ -184,7 +168,6 @@ void ROB_Init(ROB_OpEnv *op_env) {
 	rob_object.id = ROB_REC_POINTER;
 	rob_object.pid = ROB_LYR_POINTER;
 	rob_object.alpha = ROB_SPRITES_POINTER_SHADOW_ALPHA;
-	rob_object.alpha_over = ROB_SPRITES_POINTER_SHADOW_ALPHA;
 	rob_object.x = ROB_SPRITES_POINTER_SHADOW_X;
 	rob_object.y = ROB_SPRITES_POINTER_SHADOW_Y;
 	rob_object.w = ROB_SPRITES_POINTER_SHADOW_W;
@@ -194,11 +177,6 @@ void ROB_Init(ROB_OpEnv *op_env) {
 	rob_object.img_y = 0;
 	rob_object.img_w = rob_object.w;
 	rob_object.img_h = rob_object.h;
-	rob_object.img_over_surface = rob_sprites;
-	rob_object.img_over_x = rob_object.img_x;
-	rob_object.img_over_y = 0;
-	rob_object.img_over_w = rob_object.img_w;
-	rob_object.img_over_h = rob_object.img_h;
 	if (ROB_CreateObject(&rob_object)) printf("%s: %s\n", __func__, ROB_GetError());
 	/* Create a pointer */
 	if (ROB_SetObjectDefaults(&rob_object)) printf("%s: %s\n", __func__, ROB_GetError());
@@ -207,7 +185,6 @@ void ROB_Init(ROB_OpEnv *op_env) {
 	rob_object.visible = FALSE;
 	rob_object.enabled = TRUE;
 	rob_object.alpha = 255;
-	rob_object.alpha_over = 255;
 	rob_object.x = screen->w / 2;
 	rob_object.y = screen->h / 2;
 	rob_object.w = ROB_SPRITES_POINTER_W;
@@ -217,11 +194,6 @@ void ROB_Init(ROB_OpEnv *op_env) {
 	rob_object.img_y = 0;
 	rob_object.img_w = rob_object.w;
 	rob_object.img_h = rob_object.h;
-	rob_object.img_over_surface = rob_sprites;
-	rob_object.img_over_x = rob_object.img_x;
-	rob_object.img_over_y = 0;
-	rob_object.img_over_w = rob_object.img_w;
-	rob_object.img_over_h = rob_object.img_h;
 	if (ROB_CreateObject(&rob_object)) printf("%s: %s\n", __func__, ROB_GetError());
 	#ifdef DEBUG_ROB_OBJECTS
 		printf("%s: rob_lyr_root=%p\n", __func__, rob_lyr_root);
@@ -483,8 +455,8 @@ int ROB_SetObjectDefaults(ROB_Object *rob_object) {
 		rob_object->visible = ROB_INHERITED;
 		rob_object->enabled = ROB_INHERITED;
 		rob_object->alpha = ROB_INHERITED;
-		rob_object->alpha_over = ROB_INHERITED;
-		rob_object->alpha_press = ROB_INHERITED;
+		rob_object->alpha_over = ROB_UNDEFINED;
+		rob_object->alpha_press = ROB_UNDEFINED;
 		rob_object->bgcolour = ROB_UNDEFINED;
 		rob_object->bgcolour_over = ROB_UNDEFINED;
 		rob_object->bgcolour_press = ROB_UNDEFINED;
@@ -733,12 +705,11 @@ int ROB_FreeObject(ROB_Object *rob_object, int free_images_only) {
 			 any one of the error codes in ROB_engine.h */
 	
 int ROB_RenderObjects(void) {
-	int cx, cy, ix = 0, iy = 0, iw = 0, ih = 0, alpha, alpha_over, alpha_press, finalalpha = 0;
+	int cx, cy, ix = 0, iy = 0, iw = 0, ih = 0, alpha;
 	int overeventfound, presseventfound, use_rleaccel = 0;
-	int count, retval = ROB_ERROR_NONE, found;
+	int count, retval = ROB_ERROR_NONE;
 	SDL_Surface *img_surface = NULL;
 	SDL_Rect srcrect, dstrect;
-	SDL_PixelFormat *flags;
 	Uint32 bgcolour = 0;
 	
 	/* Iterate through the objects */
@@ -757,94 +728,65 @@ int ROB_RenderObjects(void) {
 			/* Get object's canvas offset */
 			ROB_GetCanvasOffset(rob_objects[count], &cx, &cy);
 
-			/* Get object's alpha_press, alpha_over and alpha */
-			alpha_press = ROB_GetAlphaPress(rob_objects[count]);
-			alpha_over = ROB_GetAlphaOver(rob_objects[count]);
+			/* Get object's alpha and alpha_{over|press} */
 			alpha = ROB_GetAlpha(rob_objects[count]);
+			if (overeventfound && rob_objects[count]->alpha_over != ROB_UNDEFINED)
+				alpha = rob_objects[count]->alpha_over;
+			if (presseventfound && rob_objects[count]->alpha_press != ROB_UNDEFINED)
+				alpha = rob_objects[count]->alpha_press;
 
-			/** bgcolour_press, bgcolour_over and bgcolour */
-			/* I've reformatted this to make it easier to understand: If a press event is found then the
-			   corresponding bgcolour_press property must contain something other than ROB_UNDEFINED else
-			   nothing will be rendered. The same thing applies to the over event and !over */
-			found = FALSE;
-			if (presseventfound) {
-				if (rob_objects[count]->bgcolour_press != ROB_UNDEFINED) {
-					found = TRUE;
-					finalalpha = alpha_press;
-					flags = rob_blend_screen->format;
-					if (finalalpha == 255) flags = screen->format;
-					bgcolour = SDL_MapRGB(flags, (rob_objects[count]->bgcolour_press >> 16) & 0xff, (rob_objects[count]->bgcolour_press >> 8) & 0xff, rob_objects[count]->bgcolour_press & 0xff);
-				}
-			} else if (overeventfound) {
-				if (rob_objects[count]->bgcolour_over != ROB_UNDEFINED) {
-					found = TRUE;
-					finalalpha = alpha_over;
-					flags = rob_blend_screen->format;
-					if (finalalpha == 255) flags = screen->format;
-					bgcolour = SDL_MapRGB(flags, (rob_objects[count]->bgcolour_over >> 16) & 0xff, (rob_objects[count]->bgcolour_over >> 8) & 0xff, rob_objects[count]->bgcolour_over & 0xff);
-				}
-			} else if (!overeventfound) {
-				if (rob_objects[count]->bgcolour != ROB_UNDEFINED) {
-					found = TRUE;
-					finalalpha = alpha;
-					flags = rob_blend_screen->format;
-					if (finalalpha == 255) flags = screen->format;
-					bgcolour = SDL_MapRGB(flags, (rob_objects[count]->bgcolour >> 16) & 0xff, (rob_objects[count]->bgcolour >> 8) & 0xff, rob_objects[count]->bgcolour & 0xff);
-				}
+			/* Get object's bgcolour and bgcolour_{over|press} */
+			bgcolour = rob_objects[count]->bgcolour;
+			if (overeventfound && rob_objects[count]->bgcolour_over != ROB_UNDEFINED)
+				bgcolour = rob_objects[count]->bgcolour_over;
+			if (presseventfound && rob_objects[count]->bgcolour_press != ROB_UNDEFINED)
+				bgcolour = rob_objects[count]->bgcolour_press;
+
+			/* Get object's img_{over_|press_}surface */
+			img_surface = rob_objects[count]->img_surface;
+			ix = rob_objects[count]->img_x; iy = rob_objects[count]->img_y;
+			iw = rob_objects[count]->img_w; ih = rob_objects[count]->img_h;
+			if (overeventfound && rob_objects[count]->img_over_surface != NULL) {
+				img_surface = rob_objects[count]->img_over_surface;
+				ix = rob_objects[count]->img_over_x; iy = rob_objects[count]->img_over_y;
+				iw = rob_objects[count]->img_over_w; ih = rob_objects[count]->img_over_h;
 			}
-			if (found) {
-				dstrect.x = cx; dstrect.y = cy;
-				dstrect.w = rob_objects[count]->w; dstrect.h = rob_objects[count]->h;
-				if (finalalpha == 255) {
+			if (presseventfound && rob_objects[count]->img_press_surface != NULL) {
+				img_surface = rob_objects[count]->img_press_surface;
+				ix = rob_objects[count]->img_press_x; iy = rob_objects[count]->img_press_y;
+				iw = rob_objects[count]->img_press_w; ih = rob_objects[count]->img_press_h;
+			}
+
+			/** Is there a colour to fill? */
+			if (bgcolour != ROB_UNDEFINED) {
+				bgcolour = SDL_MapRGB(screen->format, bgcolour >> 16 & 0xff,
+					bgcolour >> 8 & 0xff, bgcolour & 0xff);
+				if (alpha == 255) {
 					/* Fill rectangle */
+					dstrect.x = cx; dstrect.y = cy;
+					dstrect.w = rob_objects[count]->w; dstrect.h = rob_objects[count]->h;
 					if ((SDL_FillRect(screen, &dstrect, bgcolour)) < 0) {
 						sprintf(rob_last_error, "%s: Cannot fill surface: %s", __func__, SDL_GetError());
 						retval = ROB_ERROR_CANNOT_FILL_SURFACE;
 						break;
 					}
 				} else {
-					/* Fill rectangle alpha */
-					retval = ROB_FillRectA(screen, &dstrect, bgcolour, finalalpha);
+					/* Fill rectangle */
+					dstrect.x = cx; dstrect.y = cy;
+					dstrect.w = rob_objects[count]->w; dstrect.h = rob_objects[count]->h;
+					retval = ROB_FillRectA(screen, &dstrect, bgcolour, alpha);
 					if (retval) break;
 				}
 			}
 
-			/** img_press_file, img_over_file and img_file */
-			/* I've reformatted this to make it easier to understand: If a press event is found then the
-			   corresponding img_press_surface property must contain something other than NULL else
-			   nothing will be rendered. The same thing applies to the over event and !over */
-			found = FALSE;
-			if (presseventfound) {
-				if (rob_objects[count]->img_press_surface != NULL) {
-					found = TRUE;
-					ix = rob_objects[count]->img_press_x; iy = rob_objects[count]->img_press_y;
-					iw = rob_objects[count]->img_press_w; ih = rob_objects[count]->img_press_h;
-					img_surface = rob_objects[count]->img_press_surface;
-					finalalpha = alpha_press;
-				}
-			} else if (overeventfound) {
-				if (rob_objects[count]->img_over_surface != NULL) {
-					found = TRUE;
-					ix = rob_objects[count]->img_over_x; iy = rob_objects[count]->img_over_y;
-					iw = rob_objects[count]->img_over_w; ih = rob_objects[count]->img_over_h;
-					img_surface = rob_objects[count]->img_over_surface;
-					finalalpha = alpha_over;
-				}
-			} else if (!overeventfound) {
-				if (rob_objects[count]->img_surface != NULL) {
-					found = TRUE;
-					ix = rob_objects[count]->img_x; iy = rob_objects[count]->img_y;
-					iw = rob_objects[count]->img_w; ih = rob_objects[count]->img_h;
-					img_surface = rob_objects[count]->img_surface;
-					finalalpha = alpha;
-				}
-			}
-			if (found) {
+			/** Is there an image to attach? */
+			if (img_surface != NULL) {
 				/* If image region is unused then use entire image */
-				if (ix == ROB_UNDEFINED && iy == ROB_UNDEFINED && iw == ROB_UNDEFINED && ih == ROB_UNDEFINED) {
+				if (ix == ROB_UNDEFINED && iy == ROB_UNDEFINED &&
+					iw == ROB_UNDEFINED && ih == ROB_UNDEFINED) {
 					ix = 0; iy = 0; iw = img_surface->w; ih = img_surface->h;
 				}
-				if (finalalpha != 255) {
+				if (alpha != 255) {
 					/* Record surface's use of SDL_RLEACCEL.
 					   Because the surface is not compressed until the first blit,
 					   SDL_RLEACCELOK must be checked for too, I imagine as compression is pending */
@@ -852,7 +794,7 @@ int ROB_RenderObjects(void) {
 					/* Set the image surface alpha. */
 					/* Note that this removes SDL_RLEACCEL because using it with alpha
 					   is very very slow; it's restored at the end of the function */
-					if ((SDL_SetAlpha(img_surface, SDL_SRCALPHA, finalalpha)) < 0) {
+					if ((SDL_SetAlpha(img_surface, SDL_SRCALPHA, alpha)) < 0) {
 						sprintf(rob_last_error, "%s: Cannot set surface alpha: %s", __func__, SDL_GetError());
 						retval = ROB_ERROR_CANNOT_SET_SURFACE_ALPHA;
 						break;
@@ -866,11 +808,12 @@ int ROB_RenderObjects(void) {
 					retval = ROB_ERROR_CANNOT_BLIT_SURFACE;
 					break;
 				}
-				if (finalalpha != 255) {
+				if (alpha != 255) {
 					/* Disable the image surface alpha and restore SDL_RLEACCEL if set.
-					   Note that officially NOT passing the SDL_SRCALPHA flag disables alpha blits from this
-					   surface but then it's not possible to reenable SDL_RLEACCEL, so I simply set the alpha
-					   value to SDL_ALPHA_OPAQUE (255) which achieves the same result. */
+					   Note that officially NOT passing the SDL_SRCALPHA flag disables
+					   alpha blits from this surface but then it's not possible to reenable
+					   SDL_RLEACCEL, so I simply set the alpha value to SDL_ALPHA_OPAQUE
+					   (255) which achieves the same result. */
 					if ((SDL_SetAlpha(img_surface, SDL_SRCALPHA | use_rleaccel, 255)) < 0) {
 						sprintf(rob_last_error, "%s: Cannot set surface alpha: %s", __func__, SDL_GetError());
 						retval = ROB_ERROR_CANNOT_SET_SURFACE_ALPHA;
@@ -952,9 +895,7 @@ int ROB_GetCanvasOffset(ROB_Object *rob_object, int *cx, int *cy) {
  * Get Visibility                                                          *
  ***************************************************************************/
 /* This gets an object's visibility.
-   If a NULL pob is found then it will be interpreted as rob_lyr_canvas.
-   Note this could return ROB_INHERITED if the user has set the canvas or
-   root objects to ROB_INHERITED but this is unlikely ;) */
+   If a NULL pob is found then it will be interpreted as rob_lyr_canvas */
    
 /*  On exit: returns TRUE or FALSE */
 
@@ -984,16 +925,20 @@ int ROB_GetVisibility(ROB_Object *rob_object) {
 		}
 	}
 
-	return rob_object->visible;
+	/* Something valid must be returned and this may not be the
+	   case if the user has been fiddling with the system objects */
+	if (rob_object->visible < 0 || rob_object->visible > 1) {
+		return TRUE;
+	} else {
+		return rob_object->visible;
+	}
 }
 
 /***************************************************************************
  * Get Enability                                                           *
  ***************************************************************************/
 /* This gets an object's enability.
-   If a NULL pob is found then it will be interpreted as rob_lyr_canvas.
-   Note this could return ROB_INHERITED if the user has set the canvas or
-   root objects to ROB_INHERITED but this is unlikely ;) */
+   If a NULL pob is found then it will be interpreted as rob_lyr_canvas */
    
 /*  On exit: returns TRUE or FALSE */
 
@@ -1023,16 +968,20 @@ int ROB_GetEnability(ROB_Object *rob_object) {
 		}
 	}
 
-	return rob_object->enabled;
+	/* Something valid must be returned and this may not be the
+	   case if the user has been fiddling with the system objects */
+	if (rob_object->enabled < 0 || rob_object->enabled > 1) {
+		return TRUE;
+	} else {
+		return rob_object->enabled;
+	}
 }
 
 /***************************************************************************
  * Get Alpha                                                               *
  ***************************************************************************/
 /* This gets an object's alpha.
-   If a NULL pob is found then it will be interpreted as rob_lyr_canvas.
-   Note this could return ROB_INHERITED if the user has set the canvas or
-   root objects to ROB_INHERITED but this is unlikely ;) */
+   If a NULL pob is found then it will be interpreted as rob_lyr_canvas */
    
 /*  On exit: returns 0 to 255 */
 
@@ -1040,7 +989,7 @@ int ROB_GetAlpha(ROB_Object *rob_object) {
 	
 	if (rob_object == NULL || sizeof(*rob_object) != sizeof(ROB_Object)) {
 		sprintf(rob_last_error, "%s: object is invalid", __func__);
-		return 255;	/* If NULL object this stops segfaults */
+		return SDL_ALPHA_OPAQUE;	/* If NULL object this stops segfaults */
 	} else {
 		while (rob_object->alpha == ROB_INHERITED) {
 			if (rob_object == rob_lyr_root || rob_object == rob_lyr_canvas) {
@@ -1055,71 +1004,13 @@ int ROB_GetAlpha(ROB_Object *rob_object) {
 		}
 	}
 
-	return rob_object->alpha;
-}
-
-/***************************************************************************
- * Get Alpha Over                                                          *
- ***************************************************************************/
-/* This gets an object's alpha_over.
-   If a NULL pob is found then it will be interpreted as rob_lyr_canvas.
-   Note this could return ROB_INHERITED if the user has set the canvas or
-   root objects to ROB_INHERITED but this is unlikely ;) */
-   
-/*  On exit: returns 0 to 255 */
-
-int ROB_GetAlphaOver(ROB_Object *rob_object) {
-	
-	if (rob_object == NULL || sizeof(*rob_object) != sizeof(ROB_Object)) {
-		sprintf(rob_last_error, "%s: object is invalid", __func__);
-		return 255;	/* If NULL object this stops segfaults */
+	/* Something valid must be returned and this may not be the
+	   case if the user has been fiddling with the system objects */
+	if (rob_object->alpha < 0 || rob_object->alpha > SDL_ALPHA_OPAQUE) {
+		return SDL_ALPHA_OPAQUE;
 	} else {
-		while (rob_object->alpha_over == ROB_INHERITED) {
-			if (rob_object == rob_lyr_root || rob_object == rob_lyr_canvas) {
-				break;
-			} else {
-				if (rob_object->pob == NULL) {
-					rob_object = rob_lyr_canvas;
-				} else {
-					rob_object = rob_object->pob;
-				}
-			}
-		}
+		return rob_object->alpha;
 	}
-
-	return rob_object->alpha_over;
-}
-
-/***************************************************************************
- * Get Alpha Press                                                         *
- ***************************************************************************/
-/* This gets an object's alpha_press.
-   If a NULL pob is found then it will be interpreted as rob_lyr_canvas.
-   Note this could return ROB_INHERITED if the user has set the canvas or
-   root objects to ROB_INHERITED but this is unlikely ;) */
-   
-/*  On exit: returns 0 to 255 */
-
-int ROB_GetAlphaPress(ROB_Object *rob_object) {
-	
-	if (rob_object == NULL || sizeof(*rob_object) != sizeof(ROB_Object)) {
-		sprintf(rob_last_error, "%s: object is invalid", __func__);
-		return 255;	/* If NULL object this stops segfaults */
-	} else {
-		while (rob_object->alpha_press == ROB_INHERITED) {
-			if (rob_object == rob_lyr_root || rob_object == rob_lyr_canvas) {
-				break;
-			} else {
-				if (rob_object->pob == NULL) {
-					rob_object = rob_lyr_canvas;
-				} else {
-					rob_object = rob_object->pob;
-				}
-			}
-		}
-	}
-
-	return rob_object->alpha_press;
 }
 
 /***************************************************************************
