@@ -1,5 +1,5 @@
 /*  GNU Robbo
- *  Copyright (C) 2002-2009 The GNU Robbo Team (see AUTHORS).
+ *  Copyright (C) 2002-2010 The GNU Robbo Team (see AUTHORS).
  *
  *  GNU Robbo is free software - you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -89,7 +89,8 @@ update_game (void)
       /* Is Robbo currently being pulled by a magnet? */
       if (robbo.blocked == 1)
 	{
-	  play_sound (SFX_MAGNET, SND_NORM);	/* play magnet sound */
+	 
+ 	play_sound (SFX_MAGNET, SND_NORM);	/* play magnet sound */
 	  set_coords (&coords, robbo.x, robbo.y);
 	  if (can_move (coords, robbo.blocked_direction))
 	    {
@@ -457,7 +458,7 @@ update_game (void)
 				  shoot_object (coords.x, coords.y,
 						board[coords.x][coords.y].
 						direction2);
-				  play_sound (SFX_BIRD, SND_NORM);
+				  if (in_viewport(x,y)) play_sound (SFX_BIRD, SND_NORM);
 				}
 			      else
 				board[coords.x][coords.y].shooted =
@@ -632,7 +633,7 @@ update_game (void)
 				  && board[coords.x][coords.y].destroyable)
 				{
 				  if (board[coords.x][coords.y].type != BOMB)
-				    play_sound (SFX_KILL, SND_NORM);
+				    if (in_viewport(x,y)) play_sound (SFX_KILL, SND_NORM);
 				  clear_field (x, y);
 				  board[coords.x][coords.y].blowed = 1;
 				  redraw_field (coords.x, coords.y);
@@ -716,7 +717,7 @@ update_game (void)
 					    1;
 					  if (board[coords.x][coords.y].type
 					      != BOMB)
-					    play_sound (SFX_KILL, SND_NORM);
+					    if (in_viewport(x,y)) play_sound (SFX_KILL, SND_NORM);
 					}
 				    }
 				  board[x][y].returnlaser = 1;
@@ -814,7 +815,8 @@ update_game (void)
 			    }
 			  else
 			    board[x][y].state = 0;
-			  play_sound (SFX_BOX, SND_NORM);	/* play the sound */
+			  if (in_viewport(x,y)) 
+				play_sound (SFX_BOX, SND_NORM);	/* play the sound */
 			  board[coords.x][coords.y].moved = DELAY_PUSHBOX;
 			}
 		      break;
@@ -928,7 +930,7 @@ update_game (void)
 			    {
 			      if (((rand ()) & 0x07) == 0)
 				{	/* it's blaster  */
-				  play_sound (SFX_GUN, SND_NORM);
+				  if (in_viewport(x,y)) play_sound (SFX_GUN, SND_NORM);
 				  set_coords (&coords_temp, coords.x,
 					      coords.y);
 				  update_coords (&coords_temp,
@@ -989,7 +991,7 @@ update_game (void)
 			      if ((rand () & 0x07) == 0)
 				{
 				  /* gun shoots */
-				  play_sound (SFX_GUN, SND_NORM);
+				  if (in_viewport(x,y)) play_sound (SFX_GUN, SND_NORM);
 				  shoot_object (coords.x, coords.y,
 						board[coords.x][coords.y].
 						direction);
@@ -1504,7 +1506,7 @@ shoot_object (int x, int y, int direction)
     {
     case 1:
       if (board[coords.x][coords.y].type != BOMB)
-	play_sound (SFX_KILL, SND_NORM);
+	if (in_viewport(x,y)) play_sound (SFX_KILL, SND_NORM);
       board[coords.x][coords.y].blowed = 1;
       board[coords.x][coords.y].shooted = DELAY_LASER;
       if (board[x][y].solidlaser == 1)
@@ -1556,7 +1558,7 @@ blow_bomb (int x, int y)
   struct Coords coords, laserpath;
   int i;
   if (robbo.alive)
-    play_sound (SFX_BOMB, SND_NORM);
+    if (in_viewport(x,y)) play_sound (SFX_BOMB, SND_NORM);
   for (i = 0; i < 9; i++)
     {
       switch (i)
@@ -1792,23 +1794,23 @@ move_robbo (int x, int y)
 
       if (robbo.screws == 0)
 	{			/* play sound for open exit */
-	  play_sound (SFX_EXIT_OPEN, SND_NORM);
+	 play_sound (SFX_EXIT_OPEN, SND_NORM);
 	  open_exit ();
 	}
       else
-	play_sound (SFX_SCREW, SND_NORM);	/* play sound for collected screw */
+	 play_sound (SFX_SCREW, SND_NORM);	/* play sound for collected screw */
 
       scoreline.redraw |= SCORELINE_SCREWS;
       clear_field (x_tmp, y_tmp);
       break;
     case BULLET:
-      play_sound (SFX_BULLET, SND_NORM);	/* play sound for collected ammo */
+       play_sound (SFX_BULLET, SND_NORM);	/* play sound for collected ammo */
       robbo.bullets += 9;
       scoreline.redraw |= SCORELINE_BULLETS;
       clear_field (x_tmp, y_tmp);
       break;
     case KEY:
-      play_sound (SFX_KEY, SND_NORM);	/* play sound for collected key */
+       play_sound (SFX_KEY, SND_NORM);	/* play sound for collected key */
       robbo.keys++;
       scoreline.redraw |= SCORELINE_KEYS;
       clear_field (x_tmp, y_tmp);
@@ -1820,13 +1822,13 @@ move_robbo (int x, int y)
 	  scoreline.redraw |= SCORELINE_KEYS;
 	  clear_field (x_tmp, y_tmp);
 	  robbo.moved = DELAY_ROBBO;
-	  play_sound (SFX_DOOR, SND_NORM);	/* play sound for door open */
+	   play_sound (SFX_DOOR, SND_NORM);	/* play sound for door open */
 	}
       return;
     case TELEPORT:
       if (board[x_tmp][y_tmp].teleportnumber == 0)
 	break;
-      play_sound (SFX_TELEPORT, SND_NORM);	/* teleport sound */
+       play_sound (SFX_TELEPORT, SND_NORM);	/* teleport sound */
       i = 0;
       j = board[x_tmp][y_tmp].teleportnumber2;
 
@@ -1875,13 +1877,12 @@ move_robbo (int x, int y)
     case CAPSULE:
       if (robbo.exitopened)
 	{
-	  play_sound (SFX_CAPSULE, SND_NORM);
+	 play_sound (SFX_CAPSULE, SND_NORM);
 	  /* Check for pack completion */
 	  if (level_packs[selected_pack].level_selected >=
 	      level_packs[selected_pack].last_level)
 	    {
 	      game_mode = END_SCREEN;
-	      /* show_endscreen(); Redundant */
 	      return;
 	    }
 	  else
@@ -1896,8 +1897,11 @@ move_robbo (int x, int y)
 		  if (rcfile.save_frequency == RCFILE_SAVE_ON_CHANGE)
 		    {
 		      save_resource_file (path_resource_file, FALSE);
-#if defined(PLATFORM_GP2X)
+#if defined(PLATFORM_WIN32) || defined(PLATFORM_PC)
+#elif defined(PLATFORM_GP2X)
 		      system ("sync");
+#elif defined(PLATFORM_ZAURUS)
+#elif defined(PLATFORM_PSP)
 #endif
 		    }
 		}
@@ -1934,7 +1938,7 @@ move_robbo (int x, int y)
 
       if (board[x2_tmp][y2_tmp].type == EMPTY_FIELD)
 	{
-	  play_sound (SFX_BOX, SND_NORM);
+	 play_sound (SFX_BOX, SND_NORM);
 	  if (board[x_tmp][y_tmp].type == PUSH_BOX)
 	    {
 	      board[x_tmp][y_tmp].state = 1;	/* box is pushed */
@@ -1959,7 +1963,7 @@ move_robbo (int x, int y)
 
   if (robbo.moved == 0)
     robbo.moved = DELAY_ROBBO;	/* delay robbo */
-  play_sound (SFX_ROBBO, SND_NORM);
+   play_sound (SFX_ROBBO, SND_NORM);
 
 }
 
@@ -2011,7 +2015,7 @@ shoot_robbo (int x, int y)
       if (board[x_tmp][y_tmp].type != BOMB)
 	{
 	  //printf("%d\n", board[x_tmp][y_tmp].type);
-	  play_sound (SFX_KILL, SND_NORM);
+	 play_sound (SFX_KILL, SND_NORM);
 	}
       robbo.shooted = DELAY_LASER;
       robbo.bullets--;
@@ -2082,7 +2086,7 @@ kill_robbo (void)
     return;
   robbo.alive = 0;
   robbo.blocked = 0;
-  play_sound (SFX_BOMB, SND_NORM);
+ play_sound (SFX_BOMB, SND_NORM);
   create_object (robbo.x, robbo.y, BIG_BOOM);
   board[robbo.x][robbo.y].moved = DELAY_BIGBOOM;
 
@@ -2146,36 +2150,6 @@ clear_field (int x, int y)
 {
   create_object (x, y, EMPTY_FIELD);
   board[x][y].id_questionmark = 0;
-
-/*	int count; Redundant.
-
-	obj->type = EMPTY_FIELD;
-	obj->state = 0;
-	obj->direction = 0;
-	obj->destroyable = 0;
-	obj->blowable = 1;
-	obj->killing = 0;
-	obj->moved = 0;
-	obj->blowed = 0;
-	obj->shooted = 0;
-	obj->rotated = 0;
-	obj->solidlaser = 0;
-	obj->rotable = 0;
-	obj->randomrotated = 0;
-	obj->teleportnumber = 0;
-	obj->teleportnumber2 = 0;
-	obj->id_questionmark = 0;
-	obj->direction2 = 0;
-	obj->movable = 0;
-	obj->returnlaser = 0;
-	obj->shooting = 0;
-	obj->processed = cycle_count;
-	obj->redraw = TRUE;
-	 Reset the icon offsets within the image file 
-	for(count = 0; count < MAX_ICONS; count++) {
-		obj->icon[count].x = 0;
-		obj->icon[count].y = 0;
-	}*/
 }
 
 /***************************************************************************
@@ -2333,3 +2307,15 @@ clear_entire_board (void)
 	}
     }
 }
+
+/* this will return zero if x/y is in viewport and non zero otherwise */
+int in_viewport(int x, int y) {
+
+
+    if(x-viewport.x<=viewport.w && x-viewport.x>=0 && y-viewport.y<=viewport.h && y-viewport.y>=0)
+       {
+	 return 1; 
+       }
+     return 0;
+}
+
