@@ -1,7 +1,7 @@
 #ifdef USE_PIXMAP_FONT
 
 /*  GNU Robbo
- *  Copyright (C) 2002-2009 The GNU Robbo Team (see AUTHORS).
+ *  Copyright (C) 2002-2010 The GNU Robbo Team (see AUTHORS).
  *
  *  GNU Robbo is free software - you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #define FONT_WIDTH_MARKER_COLOUR 0x081828	/* 16 bit colours have a common granularity of 8 */
 #define FONT_CHAR_COLOUR 0xf8e8d8
 
-#define FONT_CHAR_COUNT 154
+#define FONT_CHAR_COUNT 220		/* There's currently an extra slot at pixmap end */
 
 #define FONT_UNSUPPORTED_CODE_POINT 95
 #define FONT_CODE_POINT_C3_84 96			/* Ä */
@@ -90,6 +90,72 @@
 #define FONT_CODE_POINT_C5_BE 150			/* ž Slovak <^ */
 #define FONT_CODE_POINT_C3_85 151			/* Å */
 #define FONT_CODE_POINT_C3_A5 152			/* å Swedish <^ */
+#define FONT_CODE_POINT_D0_90 153			/* A */
+#define FONT_CODE_POINT_D0_91 154			/* Б */
+#define FONT_CODE_POINT_D0_92 155			/* В */
+#define FONT_CODE_POINT_D0_93 156			/* Г */
+#define FONT_CODE_POINT_D0_94 157			/* Д */
+#define FONT_CODE_POINT_D0_95 158			/* Е */
+#define FONT_CODE_POINT_D0_96 159			/* Ж */
+#define FONT_CODE_POINT_D0_97 160			/* З */
+#define FONT_CODE_POINT_D0_98 161			/* И */
+#define FONT_CODE_POINT_D0_99 162			/* Й */
+#define FONT_CODE_POINT_D0_9A 163			/* К */
+#define FONT_CODE_POINT_D0_9B 164			/* Л */
+#define FONT_CODE_POINT_D0_9C 165			/* М */
+#define FONT_CODE_POINT_D0_9D 166			/* Н */
+#define FONT_CODE_POINT_D0_9E 167			/* О */
+#define FONT_CODE_POINT_D0_9F 168			/* П */
+#define FONT_CODE_POINT_D0_A0 169			/* Р */
+#define FONT_CODE_POINT_D0_A1 170			/* С */
+#define FONT_CODE_POINT_D0_A2 171			/* Т */
+#define FONT_CODE_POINT_D0_A3 172			/* У */
+#define FONT_CODE_POINT_D0_A4 173			/* Ф */
+#define FONT_CODE_POINT_D0_A5 174			/* Х */
+#define FONT_CODE_POINT_D0_A6 175			/* Ц */
+#define FONT_CODE_POINT_D0_A7 176			/* Ч */
+#define FONT_CODE_POINT_D0_A8 177			/* Ш */
+#define FONT_CODE_POINT_D0_A9 178			/* Щ */
+#define FONT_CODE_POINT_D0_AA 179			/* Ъ */
+#define FONT_CODE_POINT_D0_AB 180			/* Ы */
+#define FONT_CODE_POINT_D0_AC 181			/* Ь */
+#define FONT_CODE_POINT_D0_AD 182			/* Э */
+#define FONT_CODE_POINT_D0_AE 183			/* Ю */
+#define FONT_CODE_POINT_D0_AF 184			/* Я */
+#define FONT_CODE_POINT_D0_B0 185			/* а */
+#define FONT_CODE_POINT_D0_B1 186			/* б */
+#define FONT_CODE_POINT_D0_B2 187			/* в */
+#define FONT_CODE_POINT_D0_B3 188			/* г */
+#define FONT_CODE_POINT_D0_B4 189			/* д */
+#define FONT_CODE_POINT_D0_B5 190			/* е */
+#define FONT_CODE_POINT_D0_B6 191			/* ж */
+#define FONT_CODE_POINT_D0_B7 192			/* з */
+#define FONT_CODE_POINT_D0_B8 193			/* и */
+#define FONT_CODE_POINT_D0_B9 194			/* й */
+#define FONT_CODE_POINT_D0_BA 195			/* к */
+#define FONT_CODE_POINT_D0_BB 196			/* л */
+#define FONT_CODE_POINT_D0_BC 197			/* м */
+#define FONT_CODE_POINT_D0_BD 198			/* н */
+#define FONT_CODE_POINT_D0_BE 199			/* о */
+#define FONT_CODE_POINT_D0_BF 200			/* п */
+#define FONT_CODE_POINT_D1_80 201			/* р */
+#define FONT_CODE_POINT_D1_81 202			/* с */
+#define FONT_CODE_POINT_D1_82 203			/* т */
+#define FONT_CODE_POINT_D1_83 204			/* у */
+#define FONT_CODE_POINT_D1_84 205			/* ф */
+#define FONT_CODE_POINT_D1_85 206			/* х */
+#define FONT_CODE_POINT_D1_86 207			/* ц */
+#define FONT_CODE_POINT_D1_87 208			/* ч */
+#define FONT_CODE_POINT_D1_88 209			/* ш */
+#define FONT_CODE_POINT_D1_89 210			/* щ */
+#define FONT_CODE_POINT_D1_8A 211			/* ъ */
+#define FONT_CODE_POINT_D1_8B 212			/* ы */
+#define FONT_CODE_POINT_D1_8C 213			/* ь */
+#define FONT_CODE_POINT_D1_8D 214			/* э */
+#define FONT_CODE_POINT_D1_8E 215			/* ю */
+#define FONT_CODE_POINT_D1_8F 216			/* я */
+#define FONT_CODE_POINT_D0_81 217			/* Ё */
+#define FONT_CODE_POINT_D1_91 218			/* ё Russian <^ */
 
 
 /* Variables */
@@ -406,6 +472,138 @@ SDL_Rect get_code_point_srcrect(SDL_Surface *font, const unsigned char *utf8) {
 		index = FONT_CODE_POINT_C3_85;
 	} else if (*utf8 == 0xc3 && *(utf8 + 1) == 0xa5) {		/* å */
 		index = FONT_CODE_POINT_C3_A5;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0x90) {		/* A */
+		index = FONT_CODE_POINT_D0_90;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0x91) {		/* Б */
+		index = FONT_CODE_POINT_D0_91;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0x92) {		/* В */
+		index = FONT_CODE_POINT_D0_92;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0x93) {		/* Г */
+		index = FONT_CODE_POINT_D0_93;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0x94) {		/* Д */
+		index = FONT_CODE_POINT_D0_94;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0x95) {		/* Е */
+		index = FONT_CODE_POINT_D0_95;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0x96) {		/* Ж */
+		index = FONT_CODE_POINT_D0_96;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0x97) {		/* З */
+		index = FONT_CODE_POINT_D0_97;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0x98) {		/* И */
+		index = FONT_CODE_POINT_D0_98;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0x99) {		/* Й */
+		index = FONT_CODE_POINT_D0_99;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0x9a) {		/* К */
+		index = FONT_CODE_POINT_D0_9A;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0x9b) {		/* Л */
+		index = FONT_CODE_POINT_D0_9B;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0x9c) {		/* М */
+		index = FONT_CODE_POINT_D0_9C;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0x9d) {		/* Н */
+		index = FONT_CODE_POINT_D0_9D;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0x9e) {		/* О */
+		index = FONT_CODE_POINT_D0_9E;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0x9f) {		/* П */
+		index = FONT_CODE_POINT_D0_9F;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xa0) {		/* Р */
+		index = FONT_CODE_POINT_D0_A0;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xa1) {		/* С */
+		index = FONT_CODE_POINT_D0_A1;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xa2) {		/* Т */
+		index = FONT_CODE_POINT_D0_A2;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xa3) {		/* У */
+		index = FONT_CODE_POINT_D0_A3;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xa4) {		/* Ф */
+		index = FONT_CODE_POINT_D0_A4;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xa5) {		/* Х */
+		index = FONT_CODE_POINT_D0_A5;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xa6) {		/* Ц */
+		index = FONT_CODE_POINT_D0_A6;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xa7) {		/* Ч */
+		index = FONT_CODE_POINT_D0_A7;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xa8) {		/* Ш */
+		index = FONT_CODE_POINT_D0_A8;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xa9) {		/* Щ */
+		index = FONT_CODE_POINT_D0_A9;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xaa) {		/* Ъ */
+		index = FONT_CODE_POINT_D0_AA;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xab) {		/* Ы */
+		index = FONT_CODE_POINT_D0_AB;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xac) {		/* Ь */
+		index = FONT_CODE_POINT_D0_AC;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xad) {		/* Э */
+		index = FONT_CODE_POINT_D0_AD;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xae) {		/* Ю */
+		index = FONT_CODE_POINT_D0_AE;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xaf) {		/* Я */
+		index = FONT_CODE_POINT_D0_AF;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xb0) {		/* а */
+		index = FONT_CODE_POINT_D0_B0;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xb1) {		/* б */
+		index = FONT_CODE_POINT_D0_B1;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xb2) {		/* в */
+		index = FONT_CODE_POINT_D0_B2;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xb3) {		/* г */
+		index = FONT_CODE_POINT_D0_B3;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xb4) {		/* д */
+		index = FONT_CODE_POINT_D0_B4;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xb5) {		/* е */
+		index = FONT_CODE_POINT_D0_B5;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xb6) {		/* ж */
+		index = FONT_CODE_POINT_D0_B6;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xb7) {		/* з */
+		index = FONT_CODE_POINT_D0_B7;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xb8) {		/* и */
+		index = FONT_CODE_POINT_D0_B8;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xb9) {		/* й */
+		index = FONT_CODE_POINT_D0_B9;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xba) {		/* к */
+		index = FONT_CODE_POINT_D0_BA;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xbb) {		/* л */
+		index = FONT_CODE_POINT_D0_BB;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xbc) {		/* м */
+		index = FONT_CODE_POINT_D0_BC;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xbd) {		/* н */
+		index = FONT_CODE_POINT_D0_BD;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xbe) {		/* о */
+		index = FONT_CODE_POINT_D0_BE;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0xbf) {		/* п */
+		index = FONT_CODE_POINT_D0_BF;
+	} else if (*utf8 == 0xd1 && *(utf8 + 1) == 0x80) {		/* р */
+		index = FONT_CODE_POINT_D1_80;
+	} else if (*utf8 == 0xd1 && *(utf8 + 1) == 0x81) {		/* с */
+		index = FONT_CODE_POINT_D1_81;
+	} else if (*utf8 == 0xd1 && *(utf8 + 1) == 0x82) {		/* т */
+		index = FONT_CODE_POINT_D1_82;
+	} else if (*utf8 == 0xd1 && *(utf8 + 1) == 0x83) {		/* у */
+		index = FONT_CODE_POINT_D1_83;
+	} else if (*utf8 == 0xd1 && *(utf8 + 1) == 0x84) {		/* ф */
+		index = FONT_CODE_POINT_D1_84;
+	} else if (*utf8 == 0xd1 && *(utf8 + 1) == 0x85) {		/* х */
+		index = FONT_CODE_POINT_D1_85;
+	} else if (*utf8 == 0xd1 && *(utf8 + 1) == 0x86) {		/* ц */
+		index = FONT_CODE_POINT_D1_86;
+	} else if (*utf8 == 0xd1 && *(utf8 + 1) == 0x87) {		/* ч */
+		index = FONT_CODE_POINT_D1_87;
+	} else if (*utf8 == 0xd1 && *(utf8 + 1) == 0x88) {		/* ш */
+		index = FONT_CODE_POINT_D1_88;
+	} else if (*utf8 == 0xd1 && *(utf8 + 1) == 0x89) {		/* щ */
+		index = FONT_CODE_POINT_D1_89;
+	} else if (*utf8 == 0xd1 && *(utf8 + 1) == 0x8a) {		/* ъ */
+		index = FONT_CODE_POINT_D1_8A;
+	} else if (*utf8 == 0xd1 && *(utf8 + 1) == 0x8b) {		/* ы */
+		index = FONT_CODE_POINT_D1_8B;
+	} else if (*utf8 == 0xd1 && *(utf8 + 1) == 0x8c) {		/* ь */
+		index = FONT_CODE_POINT_D1_8C;
+	} else if (*utf8 == 0xd1 && *(utf8 + 1) == 0x8d) {		/* э */
+		index = FONT_CODE_POINT_D1_8D;
+	} else if (*utf8 == 0xd1 && *(utf8 + 1) == 0x8e) {		/* ю */
+		index = FONT_CODE_POINT_D1_8E;
+	} else if (*utf8 == 0xd1 && *(utf8 + 1) == 0x8f) {		/* я */
+		index = FONT_CODE_POINT_D1_8F;
+	} else if (*utf8 == 0xd0 && *(utf8 + 1) == 0x81) {		/* Ё */
+		index = FONT_CODE_POINT_D0_81;
+	} else if (*utf8 == 0xd1 && *(utf8 + 1) == 0x91) {		/* ё */
+		index = FONT_CODE_POINT_D1_91;
 	} else {
 		/* Unsupported code point */
 		index = FONT_UNSUPPORTED_CODE_POINT;
