@@ -1,21 +1,15 @@
-/*  GNU Robbo
- *  Copyright (C) 2002-2009 The GNU Robbo Team (see AUTHORS).
- *
- *  GNU Robbo is free software - you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
- *
- *  GNU Robbo is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the impled warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with GNU CC; see the file COPYING. If not, write to the
- *  Free Software Foundation, 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
- *
+/*
+ * GNU Robbo Copyright (C) 2002-2010 The GNU Robbo Team (see AUTHORS).
+ * GNU Robbo is free software - you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation; either version 2, or (at your option) any
+ * later version.  GNU Robbo is distributed in the hope that it will be
+ * useful, but WITHOUT ANY WARRANTY; without even the impled warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.  You should have received a
+ * copy of the GNU General Public License along with GNU CC; see the file
+ * COPYING. If not, write to the Free Software Foundation, 59 Temple Place 
+ * - Suite 330, Boston, MA 02111-1307, USA. 
  */
 
 #include "game.h"
@@ -54,7 +48,7 @@ struct k_icon_init K_icons_list[] = {
     {1, 5, KGAMEOBJ, TELEPORT, -1},
     {5, 3, KGAMEOBJ, GROUND, -1},
     {3, 1, KGAMEOBJ, WALL, -1},
-    {1,4, KGAMEOBJ, K_LASER,-1},
+    {1, 4, KGAMEOBJ, K_LASER, -1},
     {0, 0, KOBJ_S, K_LTYPE, -1},
     {0, 0, KOBJ_S, K_RMSTATE, -1},
 
@@ -62,7 +56,7 @@ struct k_icon_init K_icons_list[] = {
     {6, 2, KOBJ_S, K_ERASER, -1},
     {6, 4, KOBJ_S, K_INSERT, -1},
     {6, 3, KOBJ_S, K_SAVE, -1},
-    {8,7, KOBJ_S, K_RELOAD, -1},
+    {8, 7, KOBJ_S, K_RELOAD, -1},
     {6, 5, KOBJ_S, K_SIZE, -1},
     {8, 5, KOBJ_V, K_EXIT, 0},
     {1, 1, KOBJ_V, -1, 0},
@@ -70,7 +64,9 @@ struct k_icon_init K_icons_list[] = {
     {8, 1, KOBJ_V, K_SCROLL, 0},
     {8, 2, KOBJ_V, K_SCROLL, 2},
     {8, 4, KOBJ_V, K_SCROLL2, 2},
-    /* horizontal scrolls should at the end */
+    /*
+     * horizontal scrolls should at the end 
+     */
     {9, 4, KOBJ_V, K_SCROLL2, 1},
     {9, 2, KOBJ_V, K_SCROLL, 1},
     {9, 1, KOBJ_V, K_SCROLL, 3},
@@ -80,7 +76,6 @@ struct k_icon_init K_icons_list[] = {
     {-1, -1, -1, -1, -1,}
 };
 
-
 struct k_icons  K_icons[K_MAXICONS];
 
 /*
@@ -90,10 +85,11 @@ struct k_icons  K_icons[K_MAXICONS];
  * I decided to use global config for all objects added to the board, this 
  * way writting of the designer is easier 
  */
-int             inforedraw = 1;
-char            infostring[255];
+
+
 int             teleportnr = 1;	/* teleport number */
-int             direction = 0;	/* direction, it is the movement direction 	 */
+int             direction = 0;	/* direction, it is the movement direction 
+				 */
 int             ltype = 0;	/* laser type */
 int             rotable = 0;	/* gun rotable */
 int             shooting = 0;	/* bird shooting flag */
@@ -108,7 +104,6 @@ int             selected = -1;	/* selected icon */
 int             txt_x,
                 txt_y;
 int             lastselected = 0;
-struct game_area k_view;
 
 
 void
@@ -120,9 +115,11 @@ k_init_icons()
 	y2 = 0;
 
     int             cnt = 0;
-    
+
     for (cnt = 0; K_icons_list[cnt].x != -1; cnt++) {
-	/* if horizontal scroll icons not needed, not draw them */
+	/*
+	 * if horizontal scroll icons not needed, not draw them 
+	 */
 	if (K_icons_list[cnt].type == KOBJ_V
 	    && (K_icons_list[cnt].game_obj == K_SCROLL
 		|| K_icons_list[cnt].game_obj == K_SCROLL2)
@@ -151,7 +148,6 @@ k_init_icons()
 	case KGAMEOBJ:
 	    K_icons[cnt].blink2 = 0;
 	case KOBJ_S:
-
 	    if (x1 >= k_view.w) {
 		x1 = 0;
 		y1++;
@@ -167,10 +163,65 @@ k_init_icons()
     }
     K_icons[cnt].x = -1;
     K_icons[cnt].y = -1;
-    txt_x = x1;
-    txt_y = y1;
 }
 
+/*
+ * this will initialize konstruktor viewport 
+ * a bit copied from level_init from level.h.
+ */
+void
+konstruktor_viewport_init()
+{
+	int icons;
+	int designersize;
+
+	/* Count the number of icons used at the bottom of the screen */
+	for (icons = 0; K_icons_list[icons].x != -1 &&
+		K_icons_list[icons].type != KOBJ_V; icons++);
+
+	/* Set viewport as wide as possible */
+	k_view.w = level.w;
+	/* Enforce a minimum width */
+	if (k_view.w < DEFAULT_VIEWPORT_WIDTH - 2)
+		k_view.w = DEFAULT_VIEWPORT_WIDTH - 2;
+	/* Now adjust it to fit within the dimensions of the
+	 * screen allowing for the scroll controls column */
+	if (k_view.w >= screen->w / video.field_size - 1)
+		k_view.w = screen->w / video.field_size - 1;
+	/* Set the xoffset and centre the viewport */
+	k_view.offsetx =
+		(screen->w - (k_view.w + 1) * video.field_size) / 2 + video.xshift;
+
+	/* Calculate the depth of the icons and text area */
+	designersize = icons / k_view.w + 1;
+	if ((icons % k_view.w) &&
+		(k_view.w - icons % k_view.w < DEFAULT_VIEWPORT_WIDTH - 1))
+		designersize++;
+
+	/* Set viewport as high as possible */
+	k_view.h = level.h;
+	/* Enforce a minimum height */
+	if (k_view.h < DEFAULT_VIEWPORT_HEIGHT - 1 - designersize)
+		k_view.h = DEFAULT_VIEWPORT_HEIGHT - 1 - designersize;
+	/* Now adjust it to fit within the dimensions of the screen
+	 * allowing for the authorline, scoreline, icons and text area */
+	if (k_view.h >= screen->h / video.field_size - 3 - designersize)
+		k_view.h = screen->h / video.field_size - 3 - designersize;
+	/* Set the yoffset and centre the viewport */
+	k_view.offsety =
+		(screen->h - (k_view.h + designersize) * video.field_size) / 2 + video.yshift;
+
+	/* Calculate the position of the text area */
+	txt_x = icons % k_view.w;
+	if (k_view.w - icons % k_view.w < DEFAULT_VIEWPORT_WIDTH - 1) txt_x = 0;
+	txt_y = k_view.h + designersize - 1;
+
+	/* Set the authorline yoffset */
+	authorline.yoffset = k_view.offsety - video.field_size * 1.25;
+
+	/* Set the scoreline yoffset */
+	scoreline.yoffset = k_view.offsety + (k_view.h + designersize + 0.25) * video.field_size;
+}
 
 /*
  * 
@@ -184,6 +235,7 @@ konstruktor_init()
     hide_pointer_controls();	/* hide pointer controls, so it will not
 				 * go in the way */
     gsize = -1;			/* -1 means custom size, this can happen */
+    inforedraw = 1;
     lastclick = 0;
     clear_screen();
     level_init();
@@ -198,24 +250,26 @@ konstruktor_init()
     game_area.redraw = REDRAW_EVERYTHING;
     k_view.x = 0;
     k_view.y = 0;
-    k_view.h = viewport.h-3;
-    k_view.w = viewport.w;
-
-    k_view.offsetx =  viewport.xoffset;
-    k_view.offsety =  viewport.yoffset;
+    konstruktor_viewport_init();
     k_init_icons();
     k_redraw_all();
     konstruktor_show_game_area();
     return 0;
 }
 
-/* prepare everything for finishing designer */
+/*
+ * prepare everything for finishing designer 
+ */
 int
 konstruktor_end()
 {
     clear_screen();
     level_init();
     game_area.redraw |= REDRAW_EVERYTHING;
+    insert = 0;			/* we will forget if we wanted to insert a 
+				 * new level */
+    selected = -1;
+    lastselected = 0;
     return 0;
 }
 
@@ -240,10 +294,8 @@ konstruktor_animate(void)
     /*
      * Now iterate through every board location updating objects 
      */
-    for (y = 0; y < level.h; y++) {	/* Thunor: I have swapped these
-					 * around to process by rows */
-	for (x = 0; x < level.w; x++) {	/* Thunor: I have swapped these
-					 * around to process by rows */
+    for (y = 0; y < level.h; y++) {
+	for (x = 0; x < level.w; x++) {
 	    /*
 	     * decrement rotation delay counter if it is a gun, and needs
 	     * it 
@@ -353,7 +405,6 @@ konstruktor_show_game_area(void)
     if (game_area.redraw >= REDRAW_EVERYTHING) {
 	k_redraw_all();;
 	clear_screen();
-
 	scoreline.redraw = 0xff;
     }
     /*
@@ -535,7 +586,8 @@ konstruktor_show_game_area(void)
 		if (robbo.x == x && robbo.y == y) {	/* Is this his
 							 * location and is 
 							 * * * * * * * * * 
-							 * * he alive? */
+							 * * * * he
+							 * alive? */
 		    k_geticoncoords(3, 6, &srcrect);
 		    if (SDL_BlitSurface(icons, &srcrect, screen, &destrect)
 			< 0) {
@@ -571,29 +623,30 @@ konstruktor_click()
     /*
      * refresh all the icons 
      */
-
     if (kmx - k_view.offsetx < 0 || kmy - k_view.offsety < 0)
 	return;
     k_redraw_all();
     if (nx >= 0 && ny >= 0 && nx < k_view.w && ny < k_view.h) {
-
 	/*
 	 * ok, we have to handle map click. now we have to find out the
 	 * position 
 	 */
-	 lastselected=-1;
+	lastselected = -1;
 	nx = nx + k_view.x;
 	ny = ny + k_view.y;
 	if (selected != -1) {
+	    sprintf(infostring,
+		    "                                            ");
+	    inforedraw = 1;
 	    if (K_icons[selected].game_obj == ROBBO) {
 		redraw_field(robbo.x, robbo.y);
+		sprintf(infostring, "Robbo");
 	    }
 	    /*
 	     * do we try to delete one of the counted objects? 
 	     */
 	    switch (board[nx][ny].type) {
 	    case BULLET:
-
 		game_area.redraw = REDRAW_EVERYTHING;
 		robbo.bullets = robbo.bullets - 9;	/* bullets */
 		break;
@@ -606,31 +659,85 @@ konstruktor_click()
 		game_area.redraw = REDRAW_EVERYTHING;
 		robbo.screws--;	/* screws */
 	    }
-	    if(K_icons[selected].game_obj!=K_LASER)
+	    
+	    if (K_icons[selected].game_obj != K_LASER)
 		create_object(nx, ny, K_icons[selected].game_obj);
-	    switch (K_icons[selected].game_obj) {
-	    case K_LASER:
-		if(direction==0 || direction==2)
-		{
-		create_object(nx, ny, LASER_L);
-		}else {
-		create_object(nx, ny, LASER_D);
-		}
-		board[nx][ny].direction=direction;
-		break;
 		
+	    switch (K_icons[selected].game_obj) {
+	    case GROUND:
+		sprintf(infostring, "Ground");
+		break;
+	    case STOP:
+		sprintf(infostring, "Stop (%d on map)",
+			k_count_obj(STOP));
+		break;
+	    case BARBED_WIRE:
+		sprintf(infostring, "Radioactive Field (%d on map)",
+			k_count_obj(BARBED_WIRE));
+		break;
+	    case PUSH_BOX:
+		sprintf(infostring, "Push Box (%d on map)",
+			k_count_obj(PUSH_BOX));
+		break;
+	    case CAPSULE:
+		sprintf(infostring, "Capsule (%d on map)",
+			k_count_obj(CAPSULE));
+		break;
+	    case BOMB:
+		sprintf(infostring, "Bomb (%d on map)",
+			k_count_obj(BOMB));
+		break;
+	    case DOOR:
+		sprintf(infostring, "Door (%d on map)",
+			k_count_obj(DOOR));
+		break;
+	    case BOX:
+		sprintf(infostring, "Box (%d on map)",
+			k_count_obj(BOX));
+		break;
+	    case QUESTIONMARK:
+		sprintf(infostring, "? (%d on map)",
+			k_count_obj(QUESTIONMARK));
+		break;
+	    case EMPTY_FIELD:
+		sprintf(infostring, "Empty Field");
+		break;
+	    case BUTTERFLY:
+		sprintf(infostring, "Butterfly (%d on map)",
+			k_count_obj(BUTTERFLY));
+		break;
+	    case K_LASER:
+		if (direction == 0 || direction == 2) {
+		    create_object(nx, ny, LASER_L);
+		} else {
+		    create_object(nx, ny, LASER_D);
+		}
+		board[nx][ny].direction = direction;
+		sprintf(infostring, "Gun Fire (%d on map)",
+			k_count_obj(LASER_L) + k_count_obj(LASER_D));
+		break;
 	    case BARRIER:
 		board[nx][ny].direction = (direction >= 2) ? 2 : 0;
+		sprintf(infostring, "Force Field (%d on map)",
+			k_count_obj(BARRIER));
 		break;
 	    case SCREW:
 		robbo.screws++;
+		sprintf(infostring, "Screw (%d on map)",
+			k_count_obj(SCREW));
 		game_area.redraw = REDRAW_EVERYTHING;
 		break;
 	    case WALL:
 		board[nx][ny].state = wallnumber;;
+		if (wallnumber != 3)
+		    sprintf(infostring, "Wall");
+		else
+		    sprintf(infostring, "Black Wall");
 		break;
 	    case TELEPORT:
 		board[nx][ny].teleportnumber = teleportnr;
+		sprintf(infostring, "Teleport (%d on map)",
+			k_count_obj(TELEPORT));
 		break;
 	    case GUN:
 		board[nx][ny].solidlaser = (ltype + 1) % 3;
@@ -641,35 +748,50 @@ konstruktor_click()
 		board[nx][ny].rotated = 0;
 		board[nx][ny].rotable = rotable;
 		board[nx][ny].randomrotated = 1;
+		sprintf(infostring, "Gun (%d on map)",
+			k_count_obj(GUN));
 		break;
 	    case MAGNET:
 		board[nx][ny].direction = K_icons[selected].direction;
 		board[nx][ny].state = K_icons[selected].direction;
+		sprintf(infostring, "Magnet (%d on map)",
+			k_count_obj(MAGNET));
 		break;
 	    case BEAR:
 	    case BEAR_B:
 		board[nx][ny].direction = direction;
 		board[nx][ny].state = 0;
+		if (board[nx][ny].type == BEAR)
+		    sprintf(infostring, "Bear (%d on map)",
+		        k_count_obj(BEAR));
+		else
+		    sprintf(infostring, "Black Bear (%d on map)",
+		        k_count_obj(BEAR_B));
 		break;
 	    case BIRD:
 		board[nx][ny].direction = direction;
 		board[nx][ny].direction2 = 1;
 		board[nx][ny].state = 0;
 		board[nx][ny].shooting = shooting;
+		sprintf(infostring, "Bird (%d on map)",
+			k_count_obj(BIRD));
 		break;
 	    case KEY:
 		robbo.keys++;
+		sprintf(infostring, "Key (%d on map)",
+			k_count_obj(KEY));
 		game_area.redraw = REDRAW_EVERYTHING;
 		break;
 	    case BULLET:
 		robbo.bullets = robbo.bullets + 9;
+		sprintf(infostring, "Bullets (%dx9 on map)",
+			k_count_obj(BULLET));
 		game_area.redraw = REDRAW_EVERYTHING;
 		break;
 	    };
 	}
 	return;
     }
-
     if (lastclick > 0) {
 	return;
     }
@@ -679,161 +801,231 @@ konstruktor_click()
      */
     for (cnt = 0; K_icons[cnt].x != -1; cnt++) {
 	if (nx == K_icons[cnt].scrx && ny == K_icons[cnt].scry) {
-
+	 
+   	    K_icons[cnt].blink = DELAY_K_BLINK2; /* here we should blink clicked object, so it would not get negative index */
 	    switch (K_icons[cnt].game_obj) {
 	    case -1:
 		return;
 	    case BARBED_WIRE:
-		sprintf(infostring, "selected: radioactive field");
+		sprintf(infostring, "Radioactive Field (%d on map)",
+			k_count_obj(BARBED_WIRE));
 		inforedraw = 1;
 		break;
 	    case K_RELOAD:
-		if(cnt==lastselected) {
-			sprintf(infostring,"level reloaded");
-			clear_screen();
-			level_init();
-			if (level.w == 16 && level.h == 31)
-				gsize = 0;
-			   else if (level.w == 32 && level.h == 31)
-				gsize = 1;
-			robbo.keys = k_count_obj(KEY);	/* count keys on a map */
-			robbo.bullets = k_count_obj(BULLET) * 9;	/* count bullets */
-			game_area.redraw = REDRAW_EVERYTHING;
-			k_view.x = 0;
-			k_view.y = 0;
-			k_view.h = viewport.h - 3;
-			k_view.w = viewport.w;
-			k_view.offsetx = viewport.xoffset;
-			k_view.offsety = viewport.yoffset;
-			k_init_icons();
-			k_redraw_all();
-			} else {
-			sprintf(infostring,"click again to reload the level");
-			lastclick=50;
-			};
-		inforedraw=1;
+		if (cnt == lastselected) {
+		    sprintf(infostring, "Level reloaded");
+		    clear_screen();
+		    level_init();
+		    konstruktor_viewport_init();
+		    if (level.w == 16 && level.h == 31)
+			gsize = 0;
+		    else if (level.w == 32 && level.h == 31)
+			gsize = 1;
+		    robbo.keys = k_count_obj(KEY);	/* count keys on a 
+							 * map */
+		    robbo.bullets = k_count_obj(BULLET) * 9;	/* count
+								 * bullets 
+								 */
+		    game_area.redraw = REDRAW_EVERYTHING;
+		    k_view.x = 0;
+		    k_view.y = 0;
+
+		    k_init_icons();
+		    k_redraw_all();
+		    cnt = -1;
+		} else {
+		    sprintf(infostring, "Reload level - select again to reload");
+		    lastclick = 50;
+		};
+		inforedraw = 1;
 		break;
 	    case STOP:
-		sprintf(infostring, "selected: stop sign");
+		sprintf(infostring, "Stop (%d on map)",
+			k_count_obj(STOP));
+		inforedraw = 1;
+		break;
+	    case BARRIER:
+		sprintf(infostring, "Force Field (%d on map)",
+			k_count_obj(BARRIER));
 		inforedraw = 1;
 		break;
-
 	    case MAGNET:
-		sprintf(infostring, "magnets on the map %d",
+		sprintf(infostring, "Magnet (%d on map)",
 			k_count_obj(MAGNET));
 		inforedraw = 1;
 		break;
 	    case ROBBO:
-		sprintf(infostring, "selected: robbo");
+		sprintf(infostring, "Robbo");
 		inforedraw = 1;
 		break;
 	    case GUN:
-		sprintf(infostring, "guns on the map %d",
+		sprintf(infostring, "Gun (%d on map)",
 			k_count_obj(GUN));
 		inforedraw = 1;
 		break;
 	    case BEAR:
-		sprintf(infostring, "bears on the map %d",
+		sprintf(infostring, "Bear (%d on map)",
 			k_count_obj(BEAR));
 		inforedraw = 1;
 		break;
 	    case BEAR_B:
-		sprintf(infostring, "black bears on the map %d",
+		sprintf(infostring, "Black Bear (%d on map)",
 			k_count_obj(BEAR_B));
 		inforedraw = 1;
 		break;
-
+	    case BUTTERFLY:
+		sprintf(infostring, "Butterfly (%d on map)",
+			k_count_obj(BUTTERFLY));
+		inforedraw = 1;
+		break;
 	    case BOMB:
-		sprintf(infostring, "bombs on the map %d",
+		sprintf(infostring, "Bomb (%d on map)",
 			k_count_obj(BOMB));
 		inforedraw = 1;
 		break;
 	    case DOOR:
-		sprintf(infostring, "doors on the map %d",
+		sprintf(infostring, "Door (%d on map)",
 			k_count_obj(DOOR));
 		inforedraw = 1;
 		break;
-
 	    case BULLET:
-		sprintf(infostring, "bullets on the map %d",
+		sprintf(infostring, "Bullets (%dx9 on map)",
 			k_count_obj(BULLET));
 		inforedraw = 1;
 		break;
+	    case BOX:
+		sprintf(infostring, "Box (%d on map)",
+			k_count_obj(BOX));
+		inforedraw = 1;
+		break;
+	    case KEY:
+		sprintf(infostring, "Key (%d on map)",
+			k_count_obj(KEY));
+		inforedraw = 1;
+		break;
 	    case CAPSULE:
-		sprintf(infostring, "selected: capsule");
+		sprintf(infostring, "Capsule (%d on map)",
+			k_count_obj(CAPSULE));
+		inforedraw = 1;
+		break;
+	    case PUSH_BOX:
+		sprintf(infostring, "Push Box (%d on map)",
+			k_count_obj(PUSH_BOX));
 		inforedraw = 1;
 		break;
 	    case SCREW:
-		sprintf(infostring, "selected: screw");
+		sprintf(infostring, "Screw (%d on map)",
+			k_count_obj(SCREW));
 		inforedraw = 1;
 		break;
 	    case EMPTY_FIELD:
-		sprintf(infostring, "selected: empty field");
+		sprintf(infostring, "Empty Field");
 		inforedraw = 1;
 		break;
 	    case WALL:
 		if (cnt == selected)
 		    wallnumber = (wallnumber + 1) % 9;
 		if (wallnumber != 3)
-		    sprintf(infostring, "selected: wall");
+		    sprintf(infostring, "Wall");
 		else
-		    sprintf(infostring, "selected: black wall");
+		    sprintf(infostring, "Black Wall");
+		inforedraw = 1;
+		break;
+	    case K_LASER:
+		sprintf(infostring, "Gun Fire (%d on map)",
+			k_count_obj(LASER_L) + k_count_obj(LASER_D));
 		inforedraw = 1;
 		break;
 	    case TELEPORT:
-		sprintf(infostring, "selected: teleport");
+		sprintf(infostring, "Teleport (%d on map)",
+			k_count_obj(TELEPORT));
 		inforedraw = 1;
 
 		if (cnt == selected)
 		    teleportnr = (teleportnr % 11) + 1;
 		break;
+	    case GROUND:
+		sprintf(infostring, "Ground");
+		inforedraw = 1;
+		break;
 	    case BIRD:
-		sprintf(infostring, "birds on the map %d",
+		sprintf(infostring, "Bird (%d on map)",
 			k_count_obj(BIRD));
 		inforedraw = 1;
 
 		if (cnt == selected)
 		    shooting = (shooting + 1) % 2;
 		break;
+	    case QUESTIONMARK:
+		sprintf(infostring, "? (%d on map)",
+			k_count_obj(QUESTIONMARK));
+		inforedraw = 1;
+		break;
 	    case K_DIRECTION:
-		sprintf(infostring, "change direction");
+	    direction = (direction + 1) % 4;
+	    switch (direction) {
+	        case 0:
+	        sprintf(infostring, "Direction right");
+	        break;
+	        case 1:
+	        sprintf(infostring, "Direction down");
+	        break;
+	        case 2:
+	        sprintf(infostring, "Direction left");
+	        break;
+	        case 3:
+	        sprintf(infostring, "Direction up");
+	        break;
+		}
 		inforedraw = 1;
-
-		direction = (direction + 1) % 4;
 		break;
 	    case K_LTYPE:
 		ltype = (ltype + 1) % 3;
 		switch (ltype) {
 		case 0:
-		    sprintf(infostring, "change gun type to laser");
+		    sprintf(infostring, "Laser Gun");
 		    break;
 		case 1:
-		    sprintf(infostring, "change gun type to blaster");
+		    sprintf(infostring, "Blaster Gun");
 		    break;
 		case 2:
 		    sprintf(infostring,
-			    "change gun type to normal shooting");
+			    "Regular Gun");
 		    break;
 		}
 		inforedraw = 1;
-
 		break;
 	    case K_RMSTATE:
-		sprintf(infostring, "change move/rotate guns");
-		inforedraw = 1;
 		rmstate = (rmstate + 1) % 4;
 		rotable = (rmstate & 2) / 2;
 		movable = (rmstate & 1);
+	    switch (rmstate) {
+	        case 0:
+	        sprintf(infostring, "Fixed Gun");
+	        break;
+	        case 1:
+	        sprintf(infostring, "Moveable Gun");
+	        break;
+	        case 2:
+	        sprintf(infostring, "Rotating Gun");
+	        break;
+	        case 3:
+	        sprintf(infostring, "Moveable Rotating Gun");
+	        break;
+		}
+		inforedraw = 1;
 		break;
 	    case K_INSERT:
 		if (lastselected == cnt) {
-		    sprintf(infostring, "clear & insert on save");
+		    sprintf(infostring, "Level created");
 		    insert = 1;
 		    /*
 		     * Clear board 
 		     */
 		    robbo.screws = 0;
 		    robbo.keys = 0;
+		    robbo.bullets = 0;	/* Thunor: I added this as it was missing */
+		    scoreline.redraw = 0xff;	/* Thunor: I added this as it was missing */
 		    switch (gsize) {	/* if gsize is different than 0,1, 
 					 * we leave the map size as it is */
 		    case 0:
@@ -846,10 +1038,11 @@ konstruktor_click()
 			break;
 		    }
 		    clear_entire_board();
+		    cnt = -1;
 
 		} else {
 		    sprintf(infostring,
-			    "Click again to clear & insert on save");
+			    "New level - select again to create");
 		    lastclick = 50;
 		}
 		inforedraw = 1;
@@ -859,9 +1052,11 @@ konstruktor_click()
 		 * Clear board 
 		 */
 		if (lastselected == cnt) {
-		    sprintf(infostring, "level cleared");
+		    sprintf(infostring, "Level cleared");
 		    robbo.screws = 0;
 		    robbo.keys = 0;
+		    robbo.bullets = 0;	/* Thunor: I added this as it was missing */
+		    scoreline.redraw = 0xff;	/* Thunor: I added this as it was missing */
 		    switch (gsize) {	/* if gsize is different than 0,1, 
 					 * we leave the map size as it is */
 		    case 0:
@@ -874,8 +1069,9 @@ konstruktor_click()
 			break;
 		    }
 		    clear_entire_board();
+		    cnt = -1;
 		} else {
-		    sprintf(infostring, "Click again to clear the level");
+		    sprintf(infostring, "Clear level - select again to clear");
 		    lastclick = 50;
 		}
 		inforedraw = 1;
@@ -883,10 +1079,13 @@ konstruktor_click()
 	    case K_SAVE:
 		if (lastselected == cnt) {
 		    if (insert == 1)
-			sprintf(infostring, "level inserted at the end");
+			sprintf(infostring, "New level appended to pack");
 		    else
-			sprintf(infostring, "level overwritten");
+			sprintf(infostring, "Changes saved");
+		    cnt = -1;
+
 		    k_save_map();
+
 		    insert = 0;	/* since we saved the level, now we will
 				 * not try to insert another one */
 		} else {
@@ -894,10 +1093,10 @@ konstruktor_click()
 
 		    if (insert == 1)
 			sprintf(infostring,
-				"Click again to insert on save");
+				"Save - select again to save new level");
 		    else
 			sprintf(infostring,
-				"Click again to overwrite on save");
+				"Save - select again to save changes");
 		}
 		inforedraw = 1;
 		/*
@@ -907,21 +1106,26 @@ konstruktor_click()
 	    case K_SIZE:	/* this would set up map size, after
 				 * cleaning it */
 		gsize = (gsize + 1) % 2;
-		switch(gsize){
-			case 0:
-			level.w = 16;
-			level.h = 31;
-			k_view.x=0;
-			sprintf(infostring,"change level size to 16x31");
-			break;
-			case 1:
-			level.w = 32;
-			level.h = 31;
-			sprintf(infostring,"change level size to 32x31");
-			break;
+		switch (gsize) {
+		case 0:
+		    level.w = 16;
+		    level.h = 31;
+		    k_view.x = 0;
+		    sprintf(infostring, "Level resized to 16x31");
+		    konstruktor_viewport_init();
+		    break;
+		case 1:
+		    level.w = 32;
+		    level.h = 31;
+		    sprintf(infostring, "Level resized to 32x31");
+		    konstruktor_viewport_init();
+		    break;
 		}
+	    	robbo.screws = k_count_obj(SCREW);	/* Thunor: I added this as it was missing */
+	    	robbo.keys = k_count_obj(KEY);	/* Thunor: I added this as it was missing */
+	    	robbo.bullets = k_count_obj(BULLET) * 9;	/* Thunor: I added this as it was missing */
 		k_init_icons();
-		    game_area.redraw = REDRAW_EVERYTHING;
+		game_area.redraw = REDRAW_EVERYTHING;
 		inforedraw = 1;
 
 		break;
@@ -953,18 +1157,24 @@ konstruktor_click()
 
 		    game_mode = GAME_ON;
 		    konstruktor_end();
+		    cnt = -1;
 		} else {
-		    sprintf(infostring, "Click again to exit designer");
+		    sprintf(infostring, "Exit designer - select again to exit");
 		    lastclick = 50;	/* very long click is used as
 					 * another click */
 		    inforedraw = 1;
 		};
 		break;
 	    }
-	    if (K_icons[cnt].type == KGAMEOBJ) {
-		selected = cnt;
+	    
+	    if (cnt >= 0)	    /* that if added by Thunor should not hurt, and it should help with negative index thing */
+	    {
+	        if (K_icons[cnt].type == KGAMEOBJ) {
+	            selected = cnt;
+	        }
+/*	        K_icons[cnt].blink = DELAY_K_BLINK2; */
 	    }
-	    K_icons[cnt].blink = DELAY_K_BLINK2;
+
 	    lastselected = cnt;
 	    break;
 	}
@@ -998,14 +1208,13 @@ konstruktor_draw_icons()
 {
     int             nx,
                     ny;
-    unsigned int    color=0;
+    unsigned int    color = 0;
     int             cnt;
     SDL_Surface    *image;
     SDL_Color       bgcolor,
                     fgcolor;
     SDL_Rect        dst,
                     src;
-
     if (K_icons[selected].blink == 0)
 	K_icons[selected].blink = 1;
     for (cnt = 0; K_icons[cnt].x != -1; cnt++) {
@@ -1031,20 +1240,23 @@ konstruktor_draw_icons()
 	case KGAMEOBJ:
 	    dst.x = K_icons[cnt].scrx * video.field_size + k_view.offsetx;
 	    dst.y = K_icons[cnt].scry * video.field_size + k_view.offsety;
-	    color = K_GAMECOLOR;
+		color = skins[selected_skin].designer_GAMEOBJ_tile_colour;
 	    break;
 	case KOBJ_S:
 	    dst.y = K_icons[cnt].scry * video.field_size + k_view.offsety;
 	    dst.x = K_icons[cnt].scrx * video.field_size + k_view.offsetx;
-	    color = K_OBJSCOLOR;
+		color = skins[selected_skin].designer_OBJS_tile_colour;
 	    break;
 	case KOBJ_V:
 	    dst.x = K_icons[cnt].scrx * video.field_size + k_view.offsetx;
 	    dst.y = K_icons[cnt].scry * video.field_size + k_view.offsety;
-	    color = K_OBJVCOLOR;
+		color = skins[selected_skin].designer_OBJV_tile_colour;
 	    break;
 	}
-	SDL_FillRect(screen, &dst, color);
+
+	SDL_FillRect(screen, &dst, SDL_MapRGB(screen->format,
+		color >> 16 & 0xff, color >> 8 & 0xff, color & 0xff));
+
 	switch (K_icons[cnt].game_obj) {
 	case WALL:
 	    switch (wallnumber) {
@@ -1123,20 +1335,19 @@ konstruktor_draw_icons()
 	    SDL_BlitSurface(k_icons, &src, screen, &dst);
 	    break;
 	case K_LASER:
-		if(direction==0 || direction==2) {
-			/* vertical laser */
-			k_geticoncoords(1,4,&src);
-			SDL_BlitSurface(icons, &src, screen, &dst);
-		} else
-		{
-			k_geticoncoords(3,4,&src);
-			SDL_BlitSurface(icons, &src, screen, &dst);
-		}
-		k_geticoncoords(5, direction + 5, &src);
-		SDL_BlitSurface(k_icons, &src, screen, &dst);
-		break;
-		
-		
+	    if (direction == 0 || direction == 2) {
+		/*
+		 * vertical laser 
+		 */
+		k_geticoncoords(1, 4, &src);
+		SDL_BlitSurface(icons, &src, screen, &dst);
+	    } else {
+		k_geticoncoords(3, 4, &src);
+		SDL_BlitSurface(icons, &src, screen, &dst);
+	    }
+	    k_geticoncoords(5, direction + 5, &src);
+	    SDL_BlitSurface(k_icons, &src, screen, &dst);
+	    break;
 	case GUN:
 	    k_geticoncoords(K_icons[cnt].x, K_icons[cnt].y, &src);
 	    SDL_BlitSurface(icons, &src, screen, &dst);
@@ -1178,6 +1389,12 @@ konstruktor_draw_icons()
 		SDL_BlitSurface(k_icons, &src, screen, &dst);
 	    }
 	    break;
+	case BARRIER:
+	    k_geticoncoords(K_icons[cnt].x, K_icons[cnt].y, &src);
+	    SDL_BlitSurface(icons, &src, screen, &dst);
+	    k_geticoncoords(5, ((direction >= 2) ? 2 : 0) + 5, &src);
+	    SDL_BlitSurface(k_icons, &src, screen, &dst);
+	    break;
 	default:
 	    k_geticoncoords(K_icons[cnt].x, K_icons[cnt].y, &src);
 	    if (K_icons[cnt].type == KGAMEOBJ)
@@ -1202,18 +1419,25 @@ konstruktor_draw_icons()
     }
     if (inforedraw) {
 	inforedraw = 0;
-	dst.x = (txt_x) * video.field_size + k_view.offsetx+10;
-	dst.y = (txt_y) * video.field_size + k_view.offsety;
-	fgcolor.r = 0xff;
-	fgcolor.g = 0xff;
-	fgcolor.b = 0x00;
-	bgcolor.r = 0x00;
-	bgcolor.g = 0x00;
-	bgcolor.b = 0x00;
+
+	fgcolor.r = skins[selected_skin].designer_text_colour >> 16 & 0xff;
+	fgcolor.g = skins[selected_skin].designer_text_colour >> 8 & 0xff;
+	fgcolor.b = skins[selected_skin].designer_text_colour & 0xff;
+	bgcolor.r = skins[selected_skin].background_colour >> 16 & 0xff;
+	bgcolor.g = skins[selected_skin].background_colour >> 8 & 0xff;
+	bgcolor.b = skins[selected_skin].background_colour & 0xff;
+
 	image = TTF_RenderUTF8_Shaded(font, infostring, fgcolor, bgcolor);
 	dst.h = image->h;
-	dst.w = k_view.offsetx + video.field_size * (k_view.w + 1);
-	SDL_FillRect(screen, &dst, 0x000000);
+	dst.x = (txt_x) * video.field_size + k_view.offsetx + video.field_size / 8;
+	dst.y = (txt_y) * video.field_size + k_view.offsety;
+	/* I've centred the text vertically within field_size */
+	if (dst.h < video.field_size) dst.y += (video.field_size - dst.h) / 2;
+	dst.w = (DEFAULT_VIEWPORT_WIDTH - 1) * video.field_size - video.field_size / 8;
+
+	SDL_FillRect(screen, &dst, SDL_MapRGB(screen->format,
+		bgcolor.r, bgcolor.g, bgcolor.b));
+
 	dst.w = image->w;
 	dst.h = image->h;
 	SDL_BlitSurface(image, NULL, screen, &dst);
@@ -1301,9 +1525,16 @@ k_save_level(FILE * fdesc, int lvl)
     int             adds = 0;
     int             tn = 0;
     fprintf(fdesc, "%d\n", lvl);
-    fprintf(fdesc,
-	    "[colour]\n%06x\n[size]\n%d.%d\n\n[author]\n%s\n[notes]\nLevel edited with Gnu Robbo Designer\n[data]\n",
-	    level.colour,level.w, level.h,level.author);
+    fprintf(fdesc, "[colour]\n");
+    if (level.colour != UNDEFINED)	/* This means not set */
+    	fprintf(fdesc, "%06x\n", level.colour);
+    fprintf(fdesc, "[size]\n%d.%d\n", level.w, level.h);
+    fprintf(fdesc, "[author]\n");
+    if (level.author[0] != 0) fprintf(fdesc, "%s\n", level.author);
+    fprintf(fdesc, "[level_notes]\n");
+    /* level.notes is terminated by an enforced newline */
+    if (level.notes[0] != 0) fprintf(fdesc, "%s", level.notes);
+    fprintf(fdesc, "[data]\n");
     for (y = 0; y < level.h; y++) {
 	for (x = 0; x < level.w; x++) {
 	    if (robbo.x == x && robbo.y == y) {
@@ -1340,7 +1571,6 @@ k_save_level(FILE * fdesc, int lvl)
 		fprintf(fdesc, "%d.%d.l.%d\n", x, y,
 			board[x][y].direction);
 		break;
-
 	    case BARRIER:
 		fprintf(fdesc, "%d.%d.=.%d\n", x, y,
 			board[x][y].direction);
@@ -1374,7 +1604,6 @@ k_save_level(FILE * fdesc, int lvl)
 	    }
 	}
     }
-
     fprintf(fdesc, "[end]\n\n");
 }
 
@@ -1394,9 +1623,10 @@ k_save_map()
     char            line[1024];
     char            fname[1024];
     char            fname2[1024];
-    sprintf(fname, "%slevels/%s", PACKAGE_DATA_DIR,
-	    level_packs[selected_pack].filename);
-    sprintf(fname2, "%slevels/levelsave.tmp", PACKAGE_DATA_DIR);
+
+    sprintf(fname, "%s", level_packs[selected_pack].filename);
+    sprintf(fname2, "%s%s", level_packs[selected_pack].filename, ".tmp");
+
     fdescr = fopen(fname, "r");
     fdesc = fopen(fname2, "w+");
     if ((fdesc == NULL) || (fdescr == NULL)) {
@@ -1415,6 +1645,9 @@ k_save_map()
 	    empty++;
 	} else
 	    empty = 0;
+	/* Thunor: This is discarding a series of newlines which will
+	 * remove them from level_notes. This isn't a problem now but
+	 * it might be in the future so I'll mark it temp temp */
 	if (empty > 2)
 	    continue;
 	if (skip_level == 1) {
@@ -1494,5 +1727,3 @@ k_redraw_all()
     for (cnt = 0; K_icons[cnt].x != -1; cnt++)
 	K_icons[cnt].redraw = 1;
 };
-
-
