@@ -1,5 +1,5 @@
 /*  GNU Robbo
- *  Copyright (C) 2002-2009 The GNU Robbo Team (see AUTHORS).
+ *  Copyright (C) 2002-2010 The GNU Robbo Team (see AUTHORS).
  *
  *  GNU Robbo is free software - you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,6 +20,9 @@
 
 /* Defines */
 #define MAX_LEVEL_PACKS 55
+#define LOCAL_DATA_DIR ".gnurobbo/"
+#define LEVELS_DIR "levels/"
+#define DEFAULT_USER_LEVEL_PACK "mylevels.dat"
 #define DEFAULT_LEVEL_PACK "original.dat"
 #define DEFAULT_LEVEL_START 1	/* Start level for Robbo */
 #define DEFAULT_LEVEL_COLOUR 0x608050
@@ -32,10 +35,11 @@ struct {
 	int now_is_blinking;	/* When TRUE this will change the level background colour to white */
 	Uint32 colour;			/* The colour if found or the default_level_colour if found in the level pack */
 	Uint32 colour_override;	/* The colour if found or the default_level_colour if found in the skinrc */
+	char notes[1024];		/* This is displayed nowhere now, but contains information about notes */
 } level;
 
 struct pack {
-	char filename[100];		/* e.g. original.dat */
+	char filename[256];		/* e.g. /usr/local/share/gnurobbo/levels/original.dat or ~/.gnurobbo/levels/mylevels.dat */
 	char name[20];			/* e.g. Original */
 	int last_level;			/* e.g. 53 */
 	int level_reached;		/* e.g. 14 */
@@ -50,6 +54,7 @@ int selected_pack;			/* Which pack in the list is currently selected */
 
 /* Function prototypes */
 int level_init(void);
+void create_userpack(void);
 int find_all_dat_files(void);
 void read_level_packs(void);
 void sort_level_packs(void);
