@@ -1,5 +1,5 @@
 /*  GNU Robbo
- *  Copyright (C) 2002-2009 The GNU Robbo Team (see AUTHORS).
+ *  Copyright (C) 2002-2010 The GNU Robbo Team (see AUTHORS).
  *
  *  GNU Robbo is free software - you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,11 +19,18 @@
  */
 
 /* Defines */
-#ifdef PLATFORM_GP2X
+#if defined(PLATFORM_WIN32)
 	#define RESOURCE_FILE "gnurobborc"
-#else
+#elif defined(PLATFORM_PC)
+	#define RESOURCE_FILE ".gnurobborc"
+#elif defined(PLATFORM_GP2X)
+	#define RESOURCE_FILE "gnurobborc"
+#elif defined(PLATFORM_ZAURUS)
+	#define RESOURCE_FILE ".gnurobborc"
+#elif defined(PLATFORM_PSP)
 	#define RESOURCE_FILE ".gnurobborc"
 #endif
+
 #define RCFILE_SAVE_ON_EXIT 0
 #define RCFILE_SAVE_ON_CHANGE 1
 
