@@ -1,5 +1,5 @@
 /*  GNU Robbo
- *  Copyright (C) 2002-2009 The GNU Robbo Team (see AUTHORS).
+ *  Copyright (C) 2002-2010 The GNU Robbo Team (see AUTHORS).
  *
  *  GNU Robbo is free software - you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,20 +29,29 @@
 
 #define SKINS_DIR "skins/"
 #define SKINRC_FILE "skinrc"
-#define PNG_ICONS32   "icons32.png"
-#define PNG_ICONS16    "icons16.png"
-#define PNG_KICONS32	"k_icons32.png"
-#define PNG_KICONS16	"k_icons16.png"
-#define PNG_BGRD32	"background32.png"
-#define PNG_BGRD16	"background16.png"
-#define BMP_CIPHERS16 "ciphers16.bmp"
-#define BMP_CIPHERS32 "ciphers32.bmp"
-#define BMP_ALPHA16 "alpha16.bmp"
-#define BMP_ALPHA32 "alpha32.bmp"
+#ifdef PLATFORM_ZAURUS
+  #define IMG_ICONS32 "icons32.bmp"
+  #define IMG_ICONS16 "icons16.bmp"
+  #define IMG_KICONS32 "k_icons32.bmp"
+  #define IMG_KICONS16 "k_icons16.bmp"
+  #define IMG_BGRD32 "background32.bmp"
+  #define IMG_BGRD16 "background16.bmp"
+#else
+  #define IMG_ICONS32   "icons32.png"
+  #define IMG_ICONS16    "icons16.png"
+  #define IMG_KICONS32	"k_icons32.png"
+  #define IMG_KICONS16	"k_icons16.png"
+  #define IMG_BGRD32	"background32.png"
+  #define IMG_BGRD16	"background16.png"
+#endif
+#define IMG_CIPHERS16 "ciphers16.bmp"
+#define IMG_CIPHERS32 "ciphers32.bmp"
+#define IMG_ALPHA16 "alpha16.bmp"
+#define IMG_ALPHA32 "alpha32.bmp"
 #define TTF_ROBBO "robbo.ttf"
-#define BMP_FONT_LOWRES "font12x16.bmp"
-#define BMP_FONT_HIRES "font24x32.bmp"
-#define BMP_WM_ICON "wm_icon.bmp"
+#define IMG_FONT_LOWRES "font12x16.bmp"
+#define IMG_FONT_HIRES "font24x32.bmp"
+#define IMG_WM_ICON "wm_icon.bmp"
 
 /* Variables */
 char *data_state[] =
@@ -196,7 +205,7 @@ read_skinrc_files (void)
 		  (!strncmp (line, "[author]", 8)) ||
 		  (!strncmp (line, "[about]", 7)) ||
 		  (!strncmp (line, "[project_colours]", 17)) ||
-		  (!strncmp (line, "[soundskin]", 10)) ||
+		  (!strncmp (line, "[soundskin]", 11)) ||
 		  (!strncmp (line, "[help_tile]", 11)
 		   && project_colours_read != DATA_UNREAD))
 		{
@@ -373,7 +382,7 @@ read_skin_project_colours (void)
   char filename[256], line[1024];	/* 1024 because if fgets returns a partial line then line_count will be incremented again */
   int count, count2, line_count = 0, tag_found, tag_index, row, quit = FALSE;
   Uint32 value_read;
-#define CONFIG_ITEM_COUNT 14
+#define CONFIG_ITEM_COUNT 18
 #define CONFIG_ITEM_DATALESS 1	/* Only a tag, no following data */
 #define CONFIG_ITEM_DEPENDENT 2	/* Dependent on another tag being DATA_READ first */
 #define CONFIG_ITEM_QUIT_ON_READ 4	/* Quit once tag has been DATA_READ */
@@ -430,6 +439,14 @@ read_skin_project_colours (void)
   config_items[row].destination = &skins[selected_skin].fade_colour;
   strcpy (config_items[++row].name, "[author_text]");
   config_items[row].destination = &skins[selected_skin].author_text_colour;
+  strcpy (config_items[++row].name, "[designer_text]");
+  config_items[row].destination = &skins[selected_skin].designer_text_colour;
+  strcpy (config_items[++row].name, "[designer_GAMEOBJ_tile]");
+  config_items[row].destination = &skins[selected_skin].designer_GAMEOBJ_tile_colour;
+  strcpy (config_items[++row].name, "[designer_OBJS_tile]");
+  config_items[row].destination = &skins[selected_skin].designer_OBJS_tile_colour;
+  strcpy (config_items[++row].name, "[designer_OBJV_tile]");
+  config_items[row].destination = &skins[selected_skin].designer_OBJV_tile_colour;
   strcpy (config_items[++row].name, "[project_colours_end]");
   config_items[row].flags =
     CONFIG_ITEM_DATALESS | CONFIG_ITEM_DEPENDENT | CONFIG_ITEM_QUIT_ON_READ;
@@ -453,6 +470,10 @@ read_skin_project_colours (void)
   skins[selected_skin].help_tile_colour = HELP_TILE_COLOUR;
   skins[selected_skin].fade_colour = FADE_COLOUR;
   skins[selected_skin].author_text_colour = AUTHOR_TEXT_COLOUR;
+  skins[selected_skin].designer_text_colour = DESIGNER_TEXT_COLOUR;
+  skins[selected_skin].designer_GAMEOBJ_tile_colour = DESIGNER_GAMEOBJ_TILE_COLOUR;
+  skins[selected_skin].designer_OBJS_tile_colour = DESIGNER_OBJS_TILE_COLOUR;
+  skins[selected_skin].designer_OBJV_tile_colour = DESIGNER_OBJV_TILE_COLOUR;
 
   /* Attempt to open the skinrc file */
   strcpy (filename, PACKAGE_DATA_DIR SKINS_DIR);
@@ -860,208 +881,232 @@ read_skin_level_colour_override (void)
 void
 load_selected_skin (void)
 {
-  char filename[256];
-  int count;
-  SDL_Surface *unconverted, *converted;
+	char filename[256];
+	int count;
+	SDL_Surface *unconverted, *converted;
 
-  /* Free SDL surfaces first if they are not NULL */
-  if (icons)
-    SDL_FreeSurface (icons);
-  if (ciphers)
-    SDL_FreeSurface (ciphers);
-  if (alpha)
-    SDL_FreeSurface (alpha);
-  if (font)
-    TTF_CloseFont (font);
-  if (bgrnd)
-    SDL_FreeSurface (bgrnd);
-  bgrnd = NULL;	/* Because the background tile is optional, this now invalid pointer is nullified */
-  if (k_icons)
-    SDL_FreeSurface (k_icons);
+	/* Free SDL surfaces first if they are not NULL */
+	if (icons)
+		SDL_FreeSurface (icons);
+	if (ciphers)
+		SDL_FreeSurface (ciphers);
+	if (alpha)
+		SDL_FreeSurface (alpha);
+	if (font)
+		TTF_CloseFont (font);
+	if (bgrnd)
+		SDL_FreeSurface (bgrnd);
+	bgrnd = NULL;	/* Because the background tile is optional, this now invalid pointer is nullified */
+	if (k_icons)
+		SDL_FreeSurface (k_icons);
 
-  for (count = 0; count < 6; count++)
-    {
-      strcpy (filename, PACKAGE_DATA_DIR SKINS_DIR);
-      strcat (filename, skins[selected_skin].foldername);
-      strcat (filename, "/");
-      if (count == 0)
+	for (count = 0; count < 6; count++)
 	{
-	  /* Load the icons (sprites) */
-	  if (video.field_size == 16)
-	    {
-	      strcat (filename, PNG_ICONS16);
-	    }
-	  else if (video.field_size == 32)
-	    {
-	      strcat (filename, PNG_ICONS32);
-	    }
-	}
-      else if (count == 1)
-	{
-	  /* Load the ciphers (numbers) */
-	  if (video.field_size == 16)
-	    {
-	      strcat (filename, BMP_CIPHERS16);
-	    }
-	  else if (video.field_size == 32)
-	    {
-	      strcat (filename, BMP_CIPHERS32);
-	    }
-	}
-      else if (count == 2)
-	{
-	  /* Load the alphabet (A to Z and some miscellaneous chars) */
-	  if (video.field_size == 16)
-	    {
-	      strcat (filename, BMP_ALPHA16);
-	    }
-	  else if (video.field_size == 32)
-	    {
-	      strcat (filename, BMP_ALPHA32);
-	    }
-	}
-      else if (count == 3)
-	{
-	  /* Load the font */
-	  load_TTF_font ();
-	}
-      else if (count == 4)
-	{
-	  /* Load the background (optional) */
-	 if(video.field_size==32) 
-	  strcat (filename, PNG_BGRD32);
-	  else
-	  strcat(filename,PNG_BGRD16);
-	}
-      else if (count == 5)
-	{
-	  /* Load the konstruktor icons */
-	  if (video.field_size == 32)
-	    strcat (filename, PNG_KICONS32);
-	  else if (video.field_size == 16)
-	    strcat (filename, PNG_KICONS16);
-	}
-/* now we have the icons files in the PNG format, so we treat these differently */
-      if (count == 0 || count == 4 || count == 5)
-	{
-	  if ((unconverted = IMG_Load (filename)) == NULL)
-	    {
-	      fprintf (stdout, "Cannot load PNG image %s\n", filename);
-	      if (count == 0 || count == 5) exit (1);
-	      bgrnd = NULL;	/* no background file? well, this is not important, let's skip this one */
-	      continue;
-	    }
-	  converted = SDL_DisplayFormatAlpha (unconverted);
-	  SDL_FreeSurface (unconverted);
-	  if (converted == NULL)
-	    {
-	      fprintf (stdout, "Cannot create surface: %s\n",
-		       SDL_GetError ());
-	      if (count == 0 || count == 5) exit (1);
-	      bgrnd = NULL;	/* no background file? well, this is not important, let's skip this one */
-	      break;
-	    }
-	  if (count == 0)
-	    {
-	      icons = converted;
-	    }
-	  else if (count == 4)
-	    {
-	      bgrnd = converted;
-	    }
-	  else if (count == 5)
-	    {
-	      k_icons = converted;
-	    };
+		strcpy (filename, PACKAGE_DATA_DIR SKINS_DIR);
+		strcat (filename, skins[selected_skin].foldername);
+		strcat (filename, "/");
+		if (count == 0)
+		{
+			/* Load the icons (sprites) */
+			if (video.field_size == 16)
+			{
+				strcat (filename, IMG_ICONS16);
+			}
+			else if (video.field_size == 32)
+			{
+				strcat (filename, IMG_ICONS32);
+			}
+		}
+		else if (count == 1)
+		{
+			/* Load the ciphers (numbers) */
+			if (video.field_size == 16)
+			{
+				strcat (filename, IMG_CIPHERS16);
+			}
+			else if (video.field_size == 32)
+			{
+				strcat (filename, IMG_CIPHERS32);
+			}
+		}
+		else if (count == 2)
+		{
+			/* Load the alphabet (A to Z and some miscellaneous chars) */
+			if (video.field_size == 16)
+			{
+				strcat (filename, IMG_ALPHA16);
+			}
+			else if (video.field_size == 32)
+			{
+				strcat (filename, IMG_ALPHA32);
+			}
+		}
+		else if (count == 3)
+		{
+			/* Load the font */
+			load_TTF_font ();
+		}
+		else if (count == 4)
+		{
+			/* Load the background (optional) */
+			if(video.field_size==32) 
+				strcat (filename, IMG_BGRD32);
+			else
+				strcat(filename,IMG_BGRD16);
+		}
+		else if (count == 5)
+		{
+			/* Load the konstruktor icons */
+			if (video.field_size == 32)
+				strcat (filename, IMG_KICONS32);
+			else if (video.field_size == 16)
+				strcat (filename, IMG_KICONS16);
+		}
 
+		/* now we have the icons files in the PNG format, so we treat these differently */
+#ifndef PLATFORM_ZAURUS
+		if (count == 0 || count == 4 || count == 5)
+		{
+			if ((unconverted = IMG_Load (filename)) == NULL)
+			{
+				fprintf (stdout, "Cannot load PNG image %s\n", filename);
+				if (count == 0 || count == 5) exit (1);
+				bgrnd = NULL;	/* no background file? well, this is not important, let's skip this one */
+				continue;
+			}
+			converted = SDL_DisplayFormatAlpha (unconverted);
+			SDL_FreeSurface (unconverted);
+			if (converted == NULL)
+			{
+				fprintf (stdout, "Cannot create surface: %s\n",
+					SDL_GetError ());
+				if (count == 0 || count == 5) exit (1);
+				bgrnd = NULL;	/* no background file? well, this is not important, let's skip this one */
+				break;
+			}
+			if (count == 0)
+			{
+				icons = converted;
+			}
+			else if (count == 4)
+			{
+				bgrnd = converted;
+			}
+			else if (count == 5)
+			{
+				k_icons = converted;
+			}
+		}
+		else if (count == 1 || count == 2)
+#else
+		if (count != 3)
+#endif
+		{
+			/* Load the bitmap */
+			if ((unconverted = SDL_LoadBMP (filename)) == NULL)
+			{
+				fprintf (stdout, "Cannot load bitmap: %s\n", filename);
+				exit (1);
+			}
+			/* Set the transparent colour */
+			if (SDL_SetColorKey (unconverted, SDL_SRCCOLORKEY,
+				SDL_MapRGB (unconverted->format, 0xff, 0x00, 0xff)) < 0)
+			{
+				fprintf (stdout, "Cannot set surface colour key: %s\n",
+					SDL_GetError ());
+				exit (1);
+			}
+			/* Convert the loaded surface to the same pixel format as the screen for fast blitting */
+			converted = SDL_DisplayFormat (unconverted);
+			SDL_FreeSurface (unconverted);
+			if (converted == NULL)
+			{
+				fprintf (stdout, "Cannot create surface: %s\n",
+					SDL_GetError ());
+				exit (1);
+			}
+			if (count == 1)
+			{
+				ciphers = converted;
+			}
+			else if (count == 2)
+			{
+				alpha = converted;
+			}
+#ifdef PLATFORM_ZAURUS
+			else if (count == 0)
+			{
+				icons = converted;
+			}
+			else if (count == 4)
+			{
+				bgrnd = converted;
+				if ((SDL_SetAlpha(bgrnd, SDL_SRCALPHA, 31)) < 0) {	/* 12% */
+					fprintf(stdout, "Cannot set surface alpha: %s\n",
+						SDL_GetError());
+					exit (1);
+				}
+			}
+			else if (count == 5)
+			{
+				k_icons = converted;
+			}
+#endif
+		}
 	}
-      else if (count == 1 || count == 2)
+
+	/* Read the colours used throughout the project from the skinrc */
+	read_skin_project_colours ();
+
+	/* This is what is left of load_bitmaps() */
+	/* These SDL_Rects replace the previous duplication of surfaces */
+	if (video.field_size == 16)
 	{
-	  /* Load the bitmap */
-	  if ((unconverted = SDL_LoadBMP (filename)) == NULL)
-	    {
-	      fprintf (stdout, "Cannot load bitmap: %s\n", filename);
-	      exit (1);
-	    }
-	  /* Set the transparent colour */
-	  if (SDL_SetColorKey
-	      (unconverted, SDL_SRCCOLORKEY,
-	       SDL_MapRGB (unconverted->format, 0xff, 0x00, 0xff)) < 0)
-	    {
-	      fprintf (stdout, "Cannot set surface colour key: %s\n",
-		       SDL_GetError ());
-	      exit (1);
-	    }
-	  /* Convert the loaded surface to the same pixel format as the screen for fast blitting */
-	  converted = SDL_DisplayFormat (unconverted);
-	  SDL_FreeSurface (unconverted);
-	  if (converted == NULL)
-	    {
-	      fprintf (stdout, "Cannot create surface: %s\n",
-		       SDL_GetError ());
-	      exit (1);
-	    }
-	  if (count == 1)
-	    {
-	      ciphers = converted;
-	    }
-	  else if (count == 2)
-	    {
-	      alpha = converted;
-	    }
+		score_screw_srcrect =
+			set_rect (69, 52, video.field_size, video.field_size);
+		score_key_srcrect =
+			set_rect (103, 52, video.field_size, video.field_size);
+		score_bullet_srcrect =
+			set_rect (120, 52, video.field_size, video.field_size);
+		score_level_srcrect =
+			set_rect (137, 52, video.field_size, video.field_size);
+	}
+	else if (video.field_size == 32)
+	{
+		score_screw_srcrect =
+			set_rect (138, 104, video.field_size, video.field_size);
+		score_key_srcrect =
+			set_rect (206, 104, video.field_size, video.field_size);
+		score_bullet_srcrect =
+			set_rect (240, 104, video.field_size, video.field_size);
+		score_level_srcrect =
+			set_rect (274, 104, video.field_size, video.field_size);
 	}
-    }
 
-  /* Read the colours used throughout the project from the skinrc */
-  read_skin_project_colours ();
+	for (count = 0; count < 8; count++)
+	{
+		robbo_images_srcrect[count] =
+			set_rect ((video.field_size / 16 +
+			count * (video.field_size + video.field_size / 16)),
+			((video.field_size + video.field_size / 16) * 5 +
+			video.field_size / 16), video.field_size,
+			video.field_size);
+	}
 
-  /* This is what is left of load_bitmaps() */
-  /* These SDL_Rects replace the previous duplication of surfaces */
-  if (video.field_size == 16)
-    {
-      score_screw_srcrect =
-	set_rect (69, 52, video.field_size, video.field_size);
-      score_key_srcrect =
-	set_rect (103, 52, video.field_size, video.field_size);
-      score_bullet_srcrect =
-	set_rect (120, 52, video.field_size, video.field_size);
-      score_level_srcrect =
-	set_rect (137, 52, video.field_size, video.field_size);
-    }
-  else if (video.field_size == 32)
-    {
-      score_screw_srcrect =
-	set_rect (138, 104, video.field_size, video.field_size);
-      score_key_srcrect =
-	set_rect (206, 104, video.field_size, video.field_size);
-      score_bullet_srcrect =
-	set_rect (240, 104, video.field_size, video.field_size);
-      score_level_srcrect =
-	set_rect (274, 104, video.field_size, video.field_size);
-    }
-  for (count = 0; count < 8; count++)
-    {
-      robbo_images_srcrect[count] =
-	set_rect ((video.field_size / 16 +
-		   count * (video.field_size + video.field_size / 16)),
-		  ((video.field_size + video.field_size / 16) * 5 +
-		   video.field_size / 16), video.field_size,
-		  video.field_size);
-    }
-  for (count = 0; count < 10; count++)
-    {
-      score_images_srcrect[count] =
-	set_rect (count * (video.field_size / 2 + video.field_size / 16), 0,
-		  video.field_size / 2 + video.field_size / 16,
-		  video.field_size);
-    }
+	for (count = 0; count < 10; count++)
+	{
+		score_images_srcrect[count] =
+			set_rect (count * (video.field_size / 2 + video.field_size / 16), 0,
+			video.field_size / 2 + video.field_size / 16,
+			video.field_size);
+	}
 
-  /* and the last, but not least, we are to call soundskin init */
-  /*
-   ***** disabled
-   sound_init(skins[selected_skin].soundskin); 
-   ***** disabled
-   */
+	/* and the last, but not least, we are to call soundskin init */
+	/*
+	***** disabled
+	sound_init(skins[selected_skin].soundskin); 
+	***** disabled
+	*/
 }
 
 /***************************************************************************
@@ -1078,7 +1123,7 @@ void set_wm_icon (void) {
 	strcpy (filename, PACKAGE_DATA_DIR SKINS_DIR);
 	strcat (filename, skins[selected_skin].foldername);
 	strcat (filename, "/");
-	strcat (filename, BMP_WM_ICON);
+	strcat (filename, IMG_WM_ICON);
 
 	/* Load the bitmap */
 	if ((wm_icon = SDL_LoadBMP(filename)) == NULL) {
@@ -1105,132 +1150,127 @@ void set_wm_icon (void) {
 SDL_Surface *
 create_skin_preview (void)
 {
-  int iconoffsets1[9 * 2] =
-    { 52, 1, 1, 1, 103, 1, 18, 18, 69, 1, 137, 35, 154, 1, 1, 18, 171, 1 };
-  int iconoffsets2[9 * 2] =
-    { 1, 69, 1, 52, 69, 69, 103, 18, 52, 86, 137, 1, 18, 35, 1, 35, 120, 69 };
-  int iconoffsets3[9 * 2] =
-    { 86, 35, 69, 35, 120, 1, 52, 18, 86, 1, 103, 35, 137, 18, 154, 52, 154,
-    86
-  };
-  Uint32 tilecolour = skins[temp_selected_skin].help_tile_colour;
-  SDL_Surface *unconverted, *preview = NULL;
-  SDL_Surface *converted;
-  SDL_Rect srcrect, destrect;
-  char filename[256];
-  int xpos, ypos;
+	int iconoffsets1[9 * 2] =
+		{ 52, 1, 1, 1, 103, 1, 18, 18, 69, 1, 137, 35, 154, 1, 1, 18, 171, 1 };
+	int iconoffsets2[9 * 2] =
+		{ 1, 69, 1, 52, 69, 69, 103, 18, 52, 86, 137, 1, 18, 35, 1, 35, 120, 69 };
+	int iconoffsets3[9 * 2] =
+		{ 86, 35, 69, 35, 120, 1, 52, 18, 86, 1, 103, 35, 137, 18, 154, 52, 154,86 };
+	Uint32 tilecolour = skins[temp_selected_skin].help_tile_colour;
+	SDL_Surface *unconverted, *preview = NULL;
+	SDL_Surface *converted;
+	SDL_Rect srcrect, destrect;
+	char filename[256];
+	int xpos, ypos;
 
-  strcpy (filename, PACKAGE_DATA_DIR SKINS_DIR);
-  strcat (filename, skins[temp_selected_skin].foldername);
-  strcat (filename, "/");
-  /* Load the icons (sprites) */
-  if (video.field_size == 16)
-    {
-      strcat (filename, PNG_ICONS16);
-    }
-  else if (video.field_size == 32)
-    {
-      strcat (filename, PNG_ICONS32);
-    }
-  /* Load the bitmap */
-  if ((unconverted = IMG_Load (filename)) != NULL)
-    {
-      /* Set the transparent colour */
-      converted = SDL_DisplayFormatAlpha (unconverted);
-      SDL_FreeSurface (unconverted);
-      if (converted != NULL)
+	strcpy (filename, PACKAGE_DATA_DIR SKINS_DIR);
+	strcat (filename, skins[temp_selected_skin].foldername);
+	strcat (filename, "/");
+	
+	/* Load the icons (sprites) */
+	if (video.field_size == 16)
 	{
-	  /* Create a surface for the preview */
-	  if ((preview =
-	       SDL_CreateRGBSurface (screen->flags,
-				     video.field_size * 9 +
-				     video.field_size / 4 * 8,
-				     video.field_size * 3 +
-				     video.field_size / 4 * 2,
-				     screen->format->BitsPerPixel,
-				     screen->format->Rmask,
-				     screen->format->Gmask,
-				     screen->format->Bmask,
-				     screen->format->Amask)) != NULL)
-	    {
-	      /* Fill it with the current background colour */
-	      SDL_FillRect (preview, NULL,
-			    SDL_MapRGB (screen->format,
-					skins[selected_skin].background_colour
-					>> 16 & 0xff,
-					skins[selected_skin].background_colour
-					>> 8 & 0xff,
-					skins[selected_skin].background_colour
-					& 0xff));
-	      /* Draw a selection of icons on the preview surface */
-	      for (ypos = 0; ypos < 3; ypos++)
+		strcat (filename, IMG_ICONS16);
+	}
+	else if (video.field_size == 32)
+	{
+		strcat (filename, IMG_ICONS32);
+	}
+	
+#ifndef PLATFORM_ZAURUS
+	if ((unconverted = IMG_Load (filename)) != NULL)
+	{
+		/* Set the transparent colour */
+		converted = SDL_DisplayFormatAlpha (unconverted);
+		SDL_FreeSurface (unconverted);
+		if (converted != NULL)
 		{
-		  for (xpos = 0; xpos < 9; xpos++)
-		    {
-		      /* Draw the background tiles for the icons */
-		      destrect =
-			set_rect (xpos *
-				  (video.field_size + video.field_size / 4),
-				  ypos * (video.field_size +
-					  video.field_size / 4),
-				  video.field_size, video.field_size);
-		      SDL_FillRect (preview, &destrect,
-				    SDL_MapRGB (screen->format,
-						tilecolour >> 16 & 0xff,
-						tilecolour >> 8 & 0xff,
-						tilecolour & 0xff));
-		      /* Draw the icons */
-		      if (ypos == 0)
-			{
-			  srcrect =
-			    set_rect (iconoffsets1[xpos * 2] *
-				      video.field_size / 16,
-				      iconoffsets1[xpos * 2 +
-						   1] * video.field_size / 16,
-				      video.field_size, video.field_size);
-			}
-		      else if (ypos == 1)
-			{
-			  srcrect =
-			    set_rect (iconoffsets2[xpos * 2] *
-				      video.field_size / 16,
-				      iconoffsets2[xpos * 2 +
-						   1] * video.field_size / 16,
-				      video.field_size, video.field_size);
-			}
-		      else if (ypos == 2)
-			{
-			  srcrect =
-			    set_rect (iconoffsets3[xpos * 2] *
-				      video.field_size / 16,
-				      iconoffsets3[xpos * 2 +
-						   1] * video.field_size / 16,
-				      video.field_size, video.field_size);
-			}
-		      SDL_BlitSurface (converted, &srcrect, preview,
-				       &destrect);
-		    }
-		}
-	    }
-	  else
-	    {
-	      fprintf (stdout, "Cannot create RGB surface: %s\n",
-		       SDL_GetError ());
-	    }
-	}
-      else
+#else
+	if ((converted = SDL_LoadBMP(filename)) != NULL)
 	{
-	  fprintf (stdout, "Cannot set surface colour key: %s\n",
-		   SDL_GetError ());
+		unconverted = converted;	/* Simply stops messages about unused variables */
+		/* Set the transparent colour */
+		if (SDL_SetColorKey(converted, SDL_SRCCOLORKEY,
+			SDL_MapRGB(converted->format, 0xff, 0x00, 0xff)) == 0)
+		{
+#endif
+			/* Create a surface for the preview */
+			if ((preview =
+				SDL_CreateRGBSurface (screen->flags,
+				video.field_size * 9 + video.field_size / 4 * 8,
+				video.field_size * 3 + video.field_size / 4 * 2,
+				screen->format->BitsPerPixel,
+				screen->format->Rmask,
+				screen->format->Gmask,
+				screen->format->Bmask,
+				screen->format->Amask)) != NULL)
+			{
+				/* Fill it with the current background colour */
+				SDL_FillRect (preview, NULL,
+					SDL_MapRGB (screen->format,
+					skins[selected_skin].background_colour >> 16 & 0xff,
+					skins[selected_skin].background_colour >> 8 & 0xff,
+					skins[selected_skin].background_colour & 0xff));
+				/* Draw a selection of icons on the preview surface */
+				for (ypos = 0; ypos < 3; ypos++)
+				{
+					for (xpos = 0; xpos < 9; xpos++)
+					{
+						/* Draw the background tiles for the icons */
+						destrect =
+							set_rect (xpos * (video.field_size + video.field_size / 4),
+							ypos * (video.field_size + video.field_size / 4),
+							video.field_size, video.field_size);
+						SDL_FillRect (preview, &destrect,
+							SDL_MapRGB (screen->format,
+							tilecolour >> 16 & 0xff,
+							tilecolour >> 8 & 0xff,
+							tilecolour & 0xff));
+						/* Draw the icons */
+						if (ypos == 0)
+						{
+							srcrect =
+								set_rect (iconoffsets1[xpos * 2] * video.field_size / 16,
+								iconoffsets1[xpos * 2 + 1] * video.field_size / 16,
+								video.field_size, video.field_size);
+						}
+						else if (ypos == 1)
+						{
+							srcrect =
+								set_rect (iconoffsets2[xpos * 2] * video.field_size / 16,
+								iconoffsets2[xpos * 2 + 1] * video.field_size / 16,
+								video.field_size, video.field_size);
+						}
+						else if (ypos == 2)
+						{
+							srcrect =
+								set_rect (iconoffsets3[xpos * 2] * video.field_size / 16,
+								iconoffsets3[xpos * 2 + 1] * video.field_size / 16,
+								video.field_size, video.field_size);
+						}
+						SDL_BlitSurface (converted, &srcrect, preview, &destrect);
+					}
+				}
+			}
+			else
+			{
+				fprintf (stdout, "Cannot create RGB surface: %s\n",
+				SDL_GetError ());
+			}
+		}
+		else
+		{
+			fprintf (stdout, "Cannot set surface colour key: %s\n",
+			SDL_GetError ());
+		}
+		SDL_FreeSurface (converted);
+	}
+	else
+	{
+		fprintf (stdout, "Cannot load bitmap: %s\n", filename);
 	}
-      SDL_FreeSurface (converted);
-    }
-  else
-    {
-      fprintf (stdout, "Cannot load bitmap: %s\n", filename);
-    }
 
-  return preview;
+	return preview;
 }
 
 /***************************************************************************
@@ -1250,11 +1290,11 @@ load_TTF_font ()
   fontsize = 0;			/* Not used */
   if (video.field_size == 16)
     {
-      strcat (filename, BMP_FONT_LOWRES);
+      strcat (filename, IMG_FONT_LOWRES);
     }
   else if (video.field_size == 32)
     {
-      strcat (filename, BMP_FONT_HIRES);
+      strcat (filename, IMG_FONT_HIRES);
     }
 #else
   strcat (filename, TTF_ROBBO);
