@@ -1,5 +1,5 @@
 /*  GNU Robbo
- *  Copyright (C) 2002-2009 The GNU Robbo Team (see AUTHORS).
+ *  Copyright (C) 2002-2010 The GNU Robbo Team (see AUTHORS).
  *
  *  GNU Robbo is free software - you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -135,9 +135,10 @@ volume_up(void)
     char            tempstring[256];
     MSG_Box         temp_msg_box;
 
-    if (volume < 100) {
+    if (volume < 128)
+    {
 	volume++;
-	sprintf(tempstring, "%s: %i%%", txt_Volume, volume);
+	sprintf(tempstring, "%s: %i", txt_Volume, volume);
 	strcpy(temp_msg_box.name, MESSAGE_BOX_VOLUME_ID);
 	strcpy(temp_msg_box.message, tempstring);
 	temp_msg_box.timeout = DELAY_MESSAGE_BOX_VOLUME;
@@ -145,6 +146,15 @@ volume_up(void)
 	temp_msg_box.w = 6 * video.field_size;
 	temp_msg_box.h = 2 * video.field_size;
 	show_message_box(MESSAGE_BOX_SUB_INITIALISE, &temp_msg_box);
+#ifndef HAVE_MUSIC
+	/* If the Options screen is currently showing the Sfx Volume
+	 * then this will update temp_sfx_vol and the screen text */
+	if (game_mode == OPTIONS_SCREEN && optionspage == OPTIONS_SFX_VOL / 13)
+	{
+		temp_sfx_vol = volume;
+		options_screen.redraw |= REDRAW_INTERMEDIATE;
+    }
+#endif
     }
 }
 
@@ -158,9 +168,10 @@ volume_down(void)
     char            tempstring[256];
     MSG_Box         temp_msg_box;
 
-    if (volume > 0) {
+    if (volume > 0)
+    {
 	volume--;
-	sprintf(tempstring, "%s: %i%%", txt_Volume, volume);
+	sprintf(tempstring, "%s: %i", txt_Volume, volume);
 	strcpy(temp_msg_box.name, MESSAGE_BOX_VOLUME_ID);
 	strcpy(temp_msg_box.message, tempstring);
 	temp_msg_box.timeout = DELAY_MESSAGE_BOX_VOLUME;
@@ -168,6 +179,15 @@ volume_down(void)
 	temp_msg_box.w = 6 * video.field_size;
 	temp_msg_box.h = 2 * video.field_size;
 	show_message_box(MESSAGE_BOX_SUB_INITIALISE, &temp_msg_box);
+#ifndef HAVE_MUSIC
+	/* If the Options screen is currently showing the Sfx Volume
+	 * then this will update temp_sfx_vol and the screen text */
+	if (game_mode == OPTIONS_SCREEN && optionspage == OPTIONS_SFX_VOL / 13)
+	{
+		temp_sfx_vol = volume;
+		options_screen.redraw |= REDRAW_INTERMEDIATE;
+    }
+#endif
     }
 }
 
